@@ -1,26 +1,26 @@
 """Commands for the TurboGears command line tool."""
 
+__all__ = ['main']
+
 import glob
 import optparse
 import os
 import sys
 
 import pkg_resources
-import configobj
-
 from peak.rules import NoApplicableMethods
-import turbogears
-from turbogears.util import get_model, load_project_config, \
-        get_project_config, get_package_name
+
+from turbogears import config, database, startup, view, widgets
 from turbogears.identity import SecureObject, from_any_host
-from turbogears import config, database
+from turbogears.util import (get_model, get_project_name, get_project_config,
+    get_package_name, load_project_config)
 
 from sacommand import sacommand
 
 sys.path.insert(0, os.getcwd())
 
-no_connection_param = ["help", "list"]
-no_model_param = ["help"]
+no_connection_param = ['help', 'list']
+no_model_param = ['help']
 
 
 def silent_os_remove(fname):
@@ -31,9 +31,10 @@ def silent_os_remove(fname):
     """
     try:
         os.remove(fname)
-        return True
     except os.error:
         pass
+    else:
+        return True
     return False
 
 
@@ -49,8 +50,8 @@ class CommandWithDB(object):
         """Chooses the config file, trying to guess whether this is a
         development or installed project."""
         load_project_config(self.config)
-        self.dburi = config.get("sqlobject.dburi", None)
-        if self.dburi and self.dburi.startswith("notrans_"):
+        self.dburi = config.get('sqlobject.dburi', None)
+        if self.dburi and self.dburi.startswith('notrans_'):
             self.dburi = self.dburi[8:]
 
 
@@ -68,14 +69,13 @@ class SQL(CommandWithDB):
     need_project = True
 
     def __init__(self, version):
-        if len(sys.argv) == 1 or sys.argv[1][0] == "-":
+        if len(sys.argv) == 1 or sys.argv[1][0] == '-':
             parser = optparse.OptionParser(
-                usage="%prog sql [command]\n\n" \
-                      "hint: '%prog sql help' will list the sqlobject " \
-                      "commands",
-                version="%prog " + version)
-            parser.add_option("-c", "--config", help="config file",
-                              dest="config")
+                usage="%prog sql [command]\n\nhint: '%prog sql help'"
+                    " will list the sql specific commands",
+                version='%prog ' + version)
+            parser.add_option('-c', '--config', help="config file",
+                dest='config')
             options, args = parser.parse_args(sys.argv[1:3])
 
             if not options.config:
@@ -90,23 +90,23 @@ class SQL(CommandWithDB):
         self.find_config()
 
     def run(self):
-        """Run the sqlobject-admin tool or functions from the sacommand module."""
+        """Run the sqlobject-admin tool or sacommand module functions."""
 
-        if not "--egg" in sys.argv and not turbogears.util.get_project_name():
+        if not '--egg' in sys.argv and not get_project_name():
             print "This doesn't look like a TurboGears project."
             return
         else:
             sqlcommand = sys.argv[1]
 
-            if config.get("sqlalchemy.dburi"):
+            if config.get('sqlalchemy.dburi'):
                 try:
                     sacommand(sqlcommand, sys.argv)
                 except NoApplicableMethods:
-                    sacommand("help", [])
+                    sacommand('help', [])
                 return
 
             try:
-                from sqlobject.manager import command
+                from sqlobject.manager import command as socommand
             except ImportError:
                 from turbogears.util import missing_dependency_error
                 print missing_dependency_error('SQLObject')
@@ -123,19 +123,19 @@ class SQL(CommandWithDB):
                             % (self.config or get_project_config()))
 
             if sqlcommand not in no_model_param:
-                if not "--egg" in sys.argv:
-                    eggname = glob.glob("*.egg-info")
+                if not '--egg' in sys.argv:
+                    eggname = glob.glob('*.egg-info')
                     if not eggname or not os.path.exists(
-                            os.path.join(eggname[0], "sqlobject.txt")):
+                            os.path.join(eggname[0], 'sqlobject.txt')):
                         eggname = self.fix_egginfo(eggname)
-                    eggname = eggname[0].replace(".egg-info", "")
-                    if not "." in sys.path:
-                        sys.path.append(".")
-                        pkg_resources.working_set.add_entry(".")
+                    eggname = eggname[0].replace('.egg-info', '')
+                    if not '.' in sys.path:
+                        sys.path.append('.')
+                        pkg_resources.working_set.add_entry('.')
                     sys.argv.insert(2, eggname)
-                    sys.argv.insert(2, "--egg")
+                    sys.argv.insert(2, '--egg')
 
-            command.the_runner.run(sys.argv)
+            socommand.the_runner.run(sys.argv)
 
     def fix_egginfo(self, eggname):
         """Add egg-info directory if necessary."""
@@ -149,18 +149,18 @@ I can fix this automatically. Would you like me to?
         dofix = raw_input("Enter [y] or n: ")
         if not dofix or dofix.lower()[0] == 'y':
             oldargs = sys.argv
-            sys.argv = ["setup.py", "egg_info"]
+            sys.argv = ['setup.py', 'egg_info']
             import imp
-            imp.load_module("setup", *imp.find_module("setup", ["."]))
+            imp.load_module('setup', *imp.find_module('setup', ['.']))
             sys.argv = oldargs
 
             import setuptools
             package = setuptools.find_packages()[0]
-            eggname = glob.glob("*.egg-info")
-            sqlobjectmeta = open(os.path.join(eggname[0], "sqlobject.txt"), "w")
-            sqlobjectmeta.write("""db_module=%(package)s.model
-history_dir=$base/%(package)s/sqlobject-history
-""" % dict(package=package))
+            eggname = glob.glob('*.egg-info')
+            sqlobjectmeta = open(os.path.join(eggname[0], 'sqlobject.txt'), 'w')
+            sqlobjectmeta.write('db_module=%(package)s.model\n'
+                'history_dir=$base/%(package)s/sqlobject-history'
+                % dict(package=package))
         else:
             sys.exit(0)
         return eggname
@@ -182,7 +182,7 @@ class Shell(CommandWithDB):
         """Run the shell"""
         self.find_config()
 
-        locals = dict(__name__="tg-admin")
+        locals = dict(__name__='tg-admin')
         try:
             mod = get_model()
             if mod:
@@ -193,7 +193,7 @@ class Shell(CommandWithDB):
             print "You will not have access to your data model objects."
             print
 
-        if config.get("sqlalchemy.dburi"):
+        if config.get('sqlalchemy.dburi'):
             using_sqlalchemy = True
             database.bind_metadata()
             locals.update(session=database.session,
@@ -208,7 +208,7 @@ class Shell(CommandWithDB):
                     # database changes to be commited?
                     r = raw_input("Do you wish to commit"
                         " your database changes? [yes]")
-                    if not r.startswith("n"):
+                    if not r.startswith('n'):
                         if using_sqlalchemy:
                             self.push("session.flush()")
                         else:
@@ -221,9 +221,9 @@ class Shell(CommandWithDB):
             class CustomIPShell(iplib.InteractiveShell, CustomShellMixin):
                 def raw_input(self, *args, **kw):
                     try:
-                         # needs decoding (see below)?
-                        return iplib.InteractiveShell.raw_input(self, *args,
-                                                                **kw)
+                        # needs decoding (see below)?
+                        return iplib.InteractiveShell.raw_input(
+                            self, *args, **kw)
                     except EOFError:
                         self.commit_changes()
                         raise EOFError
@@ -263,23 +263,23 @@ class ToolboxCommand(CommandWithDB):
     desc = "Launch the TurboGears Toolbox"
 
     def __init__(self, version):
-        self.hostlist = ['127.0.0.1','::1']
+        self.hostlist = ['127.0.0.1', '::1']
 
         parser = optparse.OptionParser(
             usage="%prog toolbox [options]",
-            version="%prog " + version)
-        parser.add_option("-n", "--no-open",
+            version='%prog ' + version)
+        parser.add_option('-n', '--no-open',
             help="don't open browser automatically",
-            dest="noopen", action="store_true", default=False)
-        parser.add_option("-c", "--add-client",
+            dest='noopen', action='store_true', default=False)
+        parser.add_option('-c', '--add-client',
             help="allow client ip address specified to connect to toolbox"
                 " (can be specified more than once)",
-            dest="host", action="append", default=None)
-        parser.add_option("-p", "--port",
+            dest='host', action='append', default=None)
+        parser.add_option('-p', '--port',
             help="port to run the Toolbox on",
-            dest="port", default=7654)
-        parser.add_option("--config", help="config file to use",
-            dest="config", default=self.config or get_project_config())
+            dest='port', default=7654)
+        parser.add_option('--config', help="config file to use",
+            dest='config', default=self.config or get_project_config())
 
         options, args = parser.parse_args(sys.argv[1:])
         self.port = int(options.port)
@@ -287,29 +287,18 @@ class ToolboxCommand(CommandWithDB):
         self.config = options.config
 
         if options.host:
-            self.hostlist = self.hostlist + options.host
+            self.hostlist.extend(options.host)
 
-        turbogears.widgets.load_widgets()
+        widgets.load_widgets()
 
     def openbrowser(self):
         import webbrowser
-        webbrowser.open("http://localhost:%d" % self.port)
+        webbrowser.open('http://localhost:%d' % self.port)
 
     def run(self):
         import cherrypy
         from turbogears import toolbox
 
-        # TODO: remove this check once we convert the whole toolbox to genshi
-        try:
-            import turbokid
-        except ImportError:
-            # we could not import turbokid, the toolbox will crash with
-            # horrible tracebacks...
-            print "Please easy_install turbokid, toolbox cannot run without it"
-            # sys exit with different than zero error code in case someone
-            # is using the error code to know if it worked...
-            sys.exit(2)
-
         # Make sure we have full configuration with every option
         # in it so other plugins or whatever find what they need
         # when starting even inside the toolblox
@@ -320,33 +309,34 @@ class ToolboxCommand(CommandWithDB):
         if 'global' in conf:
             config.update({'global': conf['global']})
 
-        root = SecureObject(toolbox.Toolbox(), from_any_host(self.hostlist),
-                exclude=['noaccess'])
-
-        cherrypy.tree.mount(root, '/')
-
         # amend some parameters since we are running from the command
         # line in order to change port, log methods...
         config.update({'global': {
             'server.socket_port': self.port,
-            'server.webpath': '/',
-            'server.environment': 'development',
-            'server.log_to_screen': True,
-            'autoreload.on': False,
+            'server.webpath': '',
+            'environment': 'production',
+            'engine.autoreload.on': False,
             'server.package': 'turbogears.toolbox',
-            'log_debug_info_filter.on': False,
             'identity.failure_url': '/noaccess',
             'identity.force_external_redirect': False,
-            'tg.defaultview': 'kid',
             'tg.strict_parameters': False,
-            'kid.outputformat': 'html default',
-            'kid.encoding': 'utf-8'
+            'tg.defaultview': 'genshi',
+            'genshi.default_doctype': 'html',
+            'genshi.default_encoding': 'utf-8',
             }})
 
+        startup.config_static()
+
+        root = SecureObject(toolbox.Toolbox(),
+            from_any_host(self.hostlist), exclude=['noaccess'])
+        cherrypy.tree.mount(root, '/', config=config.app)
+
+        view.load_engines()
         if self.noopen:
-            cherrypy.server.start()
+            cherrypy.engine.start()
         else:
-            cherrypy.server.start_with_callback(self.openbrowser)
+            cherrypy.engine.start_with_callback(self.openbrowser)
+        cherrypy.engine.block()
 
 
 commands = None
@@ -355,9 +345,10 @@ def main():
     """Main command runner. Manages the primary command line arguments."""
     # add commands defined by entrypoints
     commands = {}
-    for entrypoint in pkg_resources.iter_entry_points("turbogears.command"):
+    for entrypoint in pkg_resources.iter_entry_points('turbogears.command'):
         command = entrypoint.load()
         commands[entrypoint.name] = (command.desc, entrypoint)
+    from turbogears import __version__
 
     def _help():
         """Custom help text for tg-admin."""
@@ -369,32 +360,38 @@ Usage: %s [options] <command>
 
 Options:
     -c CONFIG --config=CONFIG    Config file to use
-    -e EGG_SPEC --egg=EGG_SPEC   Run command on given Egg
+    -e EGG_SPEC --egg=EGG_SPEC   Run command on given egg
+    -h --help                    Print help (about command)
 
-Commands:""" % (turbogears.__version__, sys.argv[0])
+Commands:""" % (__version__, sys.argv[0])
 
         longest = max([len(key) for key in commands.keys()])
-        format = "%" + str(longest) + "s  %s"
+        format = '%' + str(longest) + 's  %s'
         commandlist = commands.keys()
         commandlist.sort()
         for key in commandlist:
             print format % (key, commands[key][0])
 
-    parser = optparse.OptionParser()
+    parser = optparse.OptionParser(add_help_option=False)
     parser.allow_interspersed_args = False
-    parser.add_option("-c", "--config", dest="config")
-    parser.add_option("-e", "--egg", dest="egg")
-    parser.print_help = _help
+    parser.add_option('-c', '--config', dest='config')
+    parser.add_option('-e', '--egg', dest='egg')
+    parser.add_option('-h', '--help', dest='help', action='store_true')
+    if len(sys.argv) > 1 and sys.argv[1] == 'help':
+        sys.argv[1] = '--help'
     options, args = parser.parse_args(sys.argv[1:])
 
     # if command is not found display help
-    if not args or not commands.has_key(args[0]):
+    if not args or args[0] not in commands:
         _help()
         sys.exit()
 
     commandname = args[0]
     # strip command and any global options from the sys.argv
-    sys.argv = [sys.argv[0]] + args[1:]
+    del sys.argv[1:]
+    if options.help:
+        sys.argv.append('-h')
+    sys.argv.extend(args[1:])
     command = commands[commandname][1]
     command = command.load()
 
@@ -402,8 +399,8 @@ Commands:""" % (turbogears.__version__, sys.argv[0])
         egg = pkg_resources.get_distribution(options.egg)
         os.chdir(egg.location)
 
-    if hasattr(command,"need_project"):
-        if not turbogears.util.get_project_name():
+    if hasattr(command, 'need_project'):
+        if not get_project_name():
             print "This command needs to be run from inside a project directory"
             return
         elif not options.config and not os.path.isfile(get_project_config()):
@@ -411,9 +408,8 @@ Commands:""" % (turbogears.__version__, sys.argv[0])
 If it has been renamed use:
 tg-admin --config=<FILE> %s""" % commandname
             return
+
     command.config = options.config
-    command = command(turbogears.__version__)
+    command = command(__version__)
     command.run()
 
-
-__all__ = ["main"]
