@@ -5,7 +5,6 @@
 import re
 import glob
 import os
-import os.path
 import atexit
 import optparse
 import tempfile
@@ -18,10 +17,9 @@ try:
 except ImportError:
     kid = None
 
-import turbogears
-import turbogears.i18n
 from turbogears import config
 from turbogears.i18n.pygettext import pygettext, msgfmt, catalog
+import turbogears.i18n.utils as i18n_utils
 from turbogears.command.base import silent_os_remove
 from turbogears.util import load_project_config, get_package_name
 
@@ -40,10 +38,11 @@ def copy_file(src, dest):
     fh.write(data)
     fh.close()
 
+
 _str_literal = r"""(?:'((?:[^']|\\')*)'|"((?:[^"]|\\")*)")"""
 _py_i18n_re = re.compile(r"\b_\s*\(\s*[uU]?[rR]?%s\s*\)" % _str_literal)
 _js_i18n_re = re.compile(r"\b_\s*\(\s*%s\s*\)" % _str_literal)
-_tmpl_expr_re = re.compile(r"\$\{.*?\}")
+
 
 class InternationalizationTool(object):
     """Manages i18n data via command-line interface.
@@ -58,13 +57,14 @@ class InternationalizationTool(object):
     load_config = True
     locale_dir = 'locales'
     domain = 'messages'
+    ignore_dirs = ('cvs', 'sqlobject-history')
 
     name = None
     package = None
 
     def __init__(self, version):
         parser = optparse.OptionParser(usage="""
-%prog [options] <command>
+%prog i18n [options] <command>
 
 Available commands:
   add <locale>        Creates a message catalog for specified locale
@@ -86,13 +86,9 @@ Available commands:
         parser.add_option("-G", "--no-genshi-support", default=True,
             action="store_false", dest="genshi_support",
             help="Do not extract messages from Genshi templates")
-        parser.add_option("", "--loose-kid-support",
-            action="store_true", dest="loose_kid_support",
-            help="Extract ALL messages from Kid templates (this is default)")
-        parser.add_option("", "--strict-kid-support",
-            action="store_false", dest="loose_kid_support",
-            help="Extract only messages marked with lang attribute"
-                " from Kid templates")
+        parser.add_option("", "--template-dir", default='templates',
+            action="store", dest="template_dir",
+            help="The name of directories containing templates")
         parser.add_option("", "--src-dir", default=None,
             action="store", dest="source_dir",
             help="Directory that contains source files")
@@ -107,7 +103,7 @@ Available commands:
         parser.add_option("-e", "--js-encoding",
             dest="js_encoding", default="utf-8", metavar="ENCODING",
             help="Encoding of JavaScript source files (default: UTF-8)")
-        parser.set_defaults(loose_kid_support=True, js_support=True)
+        parser.set_defaults(js_support=True)
         self.parser = parser
 
     def load_project_config(self):
@@ -121,17 +117,17 @@ Available commands:
         if self.load_config:
             load_project_config(self.config)
 
-        if config.get("i18n.locale_dir"):
-            self.locale_dir = config.get("i18n.locale_dir")
-            print 'Use %s as a locale directory' % self.locale_dir
+        if config.get('i18n.locale_dir'):
+            self.locale_dir = config.get('i18n.locale_dir')
+            print "Use %s as a locale directory" % self.locale_dir
         if config.get('i18n.domain'):
-            self.domain = config.get("i18n.domain")
-            print 'Use %s as a message domain' % self.domain
+            self.domain = config.get('i18n.domain')
+            print "Use %s as a message domain" % self.domain
 
-        if os.path.exists(self.locale_dir) and \
-                not os.path.isdir(self.locale_dir):
-            raise ProgramError, (
-                '%s is not a directory' % self.locale_dir)
+        if (os.path.exists(self.locale_dir)
+                and not os.path.isdir(self.locale_dir)):
+            raise ProgramError(
+                "%s is not a directory" % self.locale_dir)
 
         if not os.path.exists(self.locale_dir):
             os.makedirs(self.locale_dir)
@@ -170,14 +166,14 @@ Available commands:
         locale_dir_prefix = self.locale_dir.split(os.sep)
         for fname in self.list_message_catalogs():
             languages.append(fname.split(os.sep)[len(locale_dir_prefix):][0])
-        import turbogears.i18n.utils as utils
         srcdir = self.options.source_dir or get_package_name().split('.', 1)[0]
         def list_js_files():
             for root, dirs, files in os.walk(srcdir):
-                if os.path.basename(root).lower() in ('cvs', '.svn'):
+                dir = os.path.basename(root)
+                if dir.startswith('.') or dir in self.ignore_dirs:
                     continue
                 for fname in files:
-                    name, ext = os.path.splitext(fname)
+                    ext = os.path.splitext(fname)[1]
                     srcfile = os.path.join(root, fname)
                     if ext == '.js':
                         yield srcfile
@@ -188,7 +184,7 @@ Available commands:
         for locale in languages:
             def gl():
                 return locale
-            utils._get_locale = gl
+            i18n_utils._get_locale = gl
             messages = []
             for filename in list_js_files():
                 for key in self.get_strings_in_js(os.path.join(filename))[0]:
@@ -197,7 +193,7 @@ Available commands:
                     messages.append((key, msg))
             # for a final return
             header = """
-if (typeof(MESSAGES) == "undefined") {
+if (typeof(MESSAGES) == 'undefined') {
     MESSAGES = {};
 }
 
@@ -211,13 +207,13 @@ for(var i in _messages) {
   MESSAGES[_messages[i][0]] = _messages[i][1];
  }
 """
-            message_block = u",\n".join(["[%s , %s]" % (escape(msgid),
-                escape(msgstr)) for msgid, msgstr in messages]).encode("utf-8")
-            message_block = message_block + "\n"
+            message_block = u',\n'.join(['[%s , %s]' % (escape(msgid),
+                escape(msgstr)) for msgid, msgstr in messages]).encode('utf-8')
+            message_block += '\n'
             outfilename = os.path.join(srcdir, self.options.js_base_dir,
-                    'messages-%s.js' % locale)
+                'messages-%s.js' % locale)
             print "Creating message file <%s>." % outfilename
-            mf = open(outfilename, "w")
+            mf = open(outfilename, 'w')
             mf.write(header)
             mf.write(message_block)
             mf.write(footer)
@@ -240,14 +236,14 @@ for(var i in _messages) {
             dest = fname.replace('.po','.mo')
             msgfmt.make(fname, dest)
             if os.path.exists(dest):
-                print 'Compiled %s OK' % fname
+                print "Compiled %s OK" % fname
             else:
-                print 'Compilation of %s failed!' % fname
+                print "Compilation of %s failed!" % fname
 
     def _copy_file_withcheck(self, sourcefile, targetfile):
         if not (os.path.exists(targetfile) and not self.options.force_ops):
             copy_file(sourcefile, targetfile)
-            print 'Copy', sourcefile, 'to', targetfile
+            print "Copy", sourcefile, "to", targetfile
         else:
             print "File %s exists, use --force to override" % targetfile
 
@@ -272,13 +268,13 @@ for(var i in _messages) {
             if not os.path.exists(langdir):
                 os.makedirs(langdir)
 
-            sourcefile_fe = os.path.join(formencode.api.get_localedir(), code, \
-                "LC_MESSAGES","FormEncode.mo")
+            sourcefile_fe = os.path.join(formencode.api.get_localedir(), code,
+                'LC_MESSAGES', 'FormEncode.mo')
             self._copy_moduletranslation(sourcefile_fe, langdir, code)
 
-            basedir_i18n_tg = resource_filename("turbogears.i18n", "data")
-            sourcefile_tg  = os.path.join(basedir_i18n_tg, code, \
-                                          "LC_MESSAGES", "TurboGears.mo")
+            basedir_i18n_tg = resource_filename('turbogears.i18n', 'data')
+            sourcefile_tg  = os.path.join(basedir_i18n_tg, code,
+                'LC_MESSAGES', 'TurboGears.mo')
             self._copy_moduletranslation(sourcefile_tg, langdir, code)
 
             self._copy_file_withcheck(potfile, catalog_file)
@@ -289,18 +285,20 @@ for(var i in _messages) {
         genshi_files = []
         js_files = []
         srcdir = self.options.source_dir or get_package_name().split('.', 1)[0]
-        print 'Scanning source directory', srcdir
+        tmpldir = self.options.template_dir
+        print "Scanning source directory", srcdir
         for root, dirs, files in os.walk(srcdir):
-            if os.path.basename(root).lower() in ('cvs', '.svn'):
+            dir = os.path.basename(root)
+            if dir.startswith('.') or dir in self.ignore_dirs:
                 continue
             for fname in files:
-                name, ext = os.path.splitext(fname)
+                ext = os.path.splitext(fname)[1]
                 srcfile = os.path.join(root, fname)
                 if ext == '.py':
                     source_files.append(srcfile)
-                elif ext == '.kid':
+                elif ext == '.kid' and (not tmpldir or dir == tmpldir):
                     kid_files.append(srcfile)
-                elif ext == '.html':
+                elif ext == '.html' and (not tmpldir or dir == tmpldir):
                     genshi_files.append(srcfile)
                 elif ext == '.js':
                     js_files.append(srcfile)
@@ -310,14 +308,14 @@ for(var i in _messages) {
             '.pot', 'tmp', self.locale_dir)
         os.close(tmp_handle)
         potbasename = os.path.basename(tmp_potfile)[:-4]
-        pygettext_options = ['-v', '-d', potbasename, \
-                '-p', os.path.dirname(tmp_potfile)]
+        pygettext_options = ['-v', '-d', potbasename,
+            '-p', os.path.dirname(tmp_potfile)]
         if self.options.ascii_output:
             pygettext_options.insert(0, '-E')
         pygettext.sys.argv = [''] + pygettext_options + source_files
         pygettext.main()
         if not os.path.exists(tmp_potfile):
-            raise ProgramError, 'pygettext failed'
+            raise ProgramError("pygettext failed")
         atexit.register(silent_os_remove, tmp_potfile)
 
         if kid_files and self.options.kid_support:
@@ -340,9 +338,9 @@ for(var i in _messages) {
             bakfile = potfile.replace('.pot', '.bak')
             silent_os_remove(bakfile)
             os.rename(potfile, bakfile)
-            print 'Backup existing file to', bakfile
+            print "Backup existing file to", bakfile
         os.rename(tmp_potfile, potfile)
-        print 'Message templates written to', potfile
+        print "Message templates written to", potfile
 
     def scan_genshi_files(self, potfile, files):
         """Extract strings from Genhsi templates and write to pot file.
@@ -364,7 +362,7 @@ for(var i in _messages) {
 
         """
 
-        extract_strings = turbogears.i18n.pygettext.pygettext.extract_genshi_strings
+        extract_strings = pygettext.extract_genshi_strings
         messages = []
         options = {}
         for opt in ('include_attrs', 'ignore_tags'):
@@ -373,25 +371,26 @@ for(var i in _messages) {
                 options[opt] = val
 
         for fname in files:
-            print 'Working on', fname
+            print "Working on", fname
             for msg in extract_strings(fname, options or None):
-                # Genshi 0.6 adds additional 4th element, so we take
-                # care to stay compatible
+                # Genshi 0.6 adds comments as additional 4th element of msg,
+                # so we take care to stay compatible
                 lineno, text = msg[0], msg[2]
-                # Split into substrings around inline Python expressions.
-                # XXX: strings with inline Python expressions only get
-                # translated properly when the expression is at the start or
-                # end of the string.
-                for substring in _tmpl_expr_re.split(text):
-                    messages.append((lineno, fname, substring.strip()))
+                if text:
+                    if isinstance(text, tuple): # e.g. for ngettext
+                        for subtext in text:
+                            if subtext:
+                                messages.append((lineno, fname, subtext))
+                    else:
+                        messages.append((lineno, fname, text))
 
         self._write_potfile_entries(potfile, messages)
 
     def scan_kid_files(self, potfile, files):
-        """Extract strings from Genhsi templates and write to pot file."""
+        """Extract strings from Genshi templates and write to pot file."""
 
         # XXX: This duplicates functionality already present in
-        #   turbogears.i18n.pygettext! This should be recfactored.
+        #   turbogears.i18n.pygettext! This should be refactored.
         messages = []
         tags_to_ignore = ['script', 'style']
         keys = []
@@ -415,14 +414,14 @@ for(var i in _messages) {
                 keys.append(key)
 
         for fname in files:
-            print 'Working on', fname
+            print "Working on", fname
             tree = None
             fh = open(fname)
             try:
                 tree = kid.document(fh)
             except Exception, e:
                 fh.close()
-                print 'Skip %s: %s' % (fname, e)
+                print "Skip %s: %s" % (fname, e)
                 continue
             sentinel = None
             tag = None
@@ -474,7 +473,7 @@ for(var i in _messages) {
         messages = []
         keys = []
         for fname in files:
-            print 'Working on', fname
+            print "Working on", fname
             k, m = self.get_strings_in_js(fname)
             keys.extend(k)
             messages.extend(m)
@@ -484,12 +483,11 @@ for(var i in _messages) {
         if messages:
             fd = open(potfile, 'at+')
             for linenumber, fname, text in messages:
-                if text == '':
-                    continue
-                text = catalog.normalize(text.encode('utf-8'))
-                fd.write('#: %s:%s\n' % (fname, linenumber))
-                fd.write('msgid %s\n' % text)
-                fd.write('msgstr ""\n\n')
+                if text:
+                    text = catalog.normalize(text.encode('utf-8'))
+                    fd.write('#: %s:%s\n' % (fname, linenumber))
+                    fd.write('msgid %s\n' % text)
+                    fd.write('msgstr ""\n\n')
             fd.close()
 
     def get_potfile_path(self):
