@@ -5,24 +5,21 @@ a new, ready-to-run project.
 
 """
 
-import pkg_resources
-import re
+import optparse
 import os
-import os.path
+import re
 import shutil
 import stat
-import optparse
 import sys
+
+import pkg_resources
 import turbogears
+
 from paste.script import templates, create_distro
 
-try:
-    set
-except NameError: # Python 2.3
-    from sets import Set as set
 
-beginning_letter = re.compile(r"^[^a-z]*")
-valid_only = re.compile(r"[^a-z0-9_]")
+beginning_letter = re.compile(r'^[^a-z]*')
+valid_only = re.compile(r'[^a-z0-9_]')
 
 
 class TGTemplate(templates.Template):
@@ -31,50 +28,43 @@ class TGTemplate(templates.Template):
         vars.setdefault('turbogearsversion',
                 pkg_resources.get_distribution('turbogears').version)
         vars.setdefault('sys_executable', os.path.normpath(sys.executable))
-        # define version-compatible decorator syntax
-        if sys.version_info >= (2, 4):
-            vars['b'] = '@'
-            vars['e'] = ''
-        else:
-            vars['b'] = '['
-            vars['e'] = ']'
         super(TGTemplate, self).run(command, output_dirs, vars)
 
 
 class BaseTemplate(TGTemplate):
-    egg_plugins = ["TurboGears"]
+    egg_plugins = ['TurboGears']
     _template_dir = pkg_resources.resource_filename(
-                        "turbogears.qstemplates",
-                        "qsbase"
+                        'turbogears.qstemplates',
+                        'qsbase'
                     )
     summary = "tg base template"
     use_cheetah = True
 
 
 class TurbogearsTemplate(TGTemplate):
-    required_templates = ["tgbase"]
+    required_templates = ['tgbase']
     _template_dir = pkg_resources.resource_filename(
-                            "turbogears.qstemplates",
-                            "quickstart")
+                            'turbogears.qstemplates',
+                            'quickstart')
     summary = "web framework"
     use_cheetah = True
 
 
 class TGBig(TGTemplate):
-    required_templates = ["turbogears"]
+    required_templates = ['turbogears']
     _template_dir = pkg_resources.resource_filename(
-                            "turbogears.qstemplates",
-                            "quickstartbig")
+                            'turbogears.qstemplates',
+                            'quickstartbig')
     summary = "For more complex projects"
     use_cheetah = True
 
     def post(self, command, output_dir, vars):
-        packagedir = os.path.join(output_dir, vars["package"])
-        controllersdir = os.path.join(packagedir, "controllers")
-        controllersfile = os.path.join(packagedir, "controllers.py")
-        rootfile = os.path.join(controllersdir, "root.py")
-        if os.path.exists(controllersdir) and \
-            os.path.exists(controllersfile):
+        packagedir = os.path.join(output_dir, vars['package'])
+        controllersdir = os.path.join(packagedir, 'controllers')
+        controllersfile = os.path.join(packagedir, 'controllers.py')
+        rootfile = os.path.join(controllersdir, 'root.py')
+        if (os.path.exists(controllersdir)
+                and os.path.exists(controllersfile)):
             controllerstext = open(controllersfile).read()
             roottext = open(rootfile).read()
             from paste.script.copydir import query_interactive
@@ -101,15 +91,15 @@ class TGBig(TGTemplate):
 
 
 class TGWidgetTemplate(TGTemplate):
-    required_templates = ["tgbase"]
+    required_templates = ['tgbase']
     _template_dir = pkg_resources.resource_filename(
-                            "turbogears.qstemplates",
-                            "widget")
+                            'turbogears.qstemplates',
+                            'widget')
     summary = "TurboGears widget projects"
 
 
 def get_requirement(name, pkg=None):
-    dist = pkg_resources.get_distribution("TurboGears")
+    dist = pkg_resources.get_distribution('TurboGears')
     for r in set(dist.requires((name,))) - set(dist.requires()):
         if r.project_name.lower() == (pkg or name):
             return r
@@ -124,48 +114,70 @@ class quickstart:
 
     name = None
     package = None
-    templates = "turbogears"
+    templates = 'turbogears'
     svn_repository = None
     sqlalchemy = False
     sqlobject = False
     elixir = False
     identity = False
+    # we ask user for identity usage in the default settings
+    prompt_identity = True
 
     def __init__(self, version):
         parser = optparse.OptionParser(
                     usage="%prog quickstart [options] [project name]",
                     version="%prog " + version)
         parser.add_option("-s", "--sqlalchemy",
-            help="use SQLAlchemy instead of SQLObject",
-            action="store_true", dest="sqlalchemy", default = False)
+            help="use SQLAlchemy instead of SQLObject (the default)",
+            action="store_true", dest="sqlalchemy", default=False)
         parser.add_option("-e", "--elixir",
             help="use SQLAlchemy Elixir instead of SQLObject",
-            action="store_true", dest="elixir", default = False)
+            action="store_true", dest="elixir", default=False)
         parser.add_option("-o", "--sqlobject",
             help="use SQLObject instead of SQLAlchemy",
-            action="store_true", dest="sqlobject", default = False)
+            action="store_true", dest="sqlobject", default=False)
         parser.add_option("-i", "--identity",
             help="provide Identity support",
-            action="store_true", dest="identity", default = False)
+            action="store_true", dest="identity", default=False)
+        parser.add_option("", "--no-identity",
+            help="don't prompt for Identity support (ignored with -i)",
+            action="store_false", dest="prompt_identity", default=True)
+        parser.add_option("", "--table-prefix",
+            help="add the specified prefix to all generated tables",
+            dest="table_prefix")
         parser.add_option("-p", "--package",
             help="package name for the code",
             dest="package")
         parser.add_option("-t", "--templates",
             help="user specific templates",
-            dest="templates", default = self.templates)
+            dest="templates", default=self.templates)
         parser.add_option("-r", "--svn-repository", metavar="REPOS",
             help="create project in given SVN repository",
-            dest="svn_repository", default = self.svn_repository)
+            dest="svn_repository", default=self.svn_repository)
+
         parser.add_option("--dry-run",
             help="dry run (don't actually do anything)",
             action="store_true", dest="dry_run")
 
         options, args = parser.parse_args()
         self.__dict__.update(options.__dict__)
-        if not True in [self.elixir, self.sqlalchemy, self.sqlobject]:
-            self.sqlobject = True
+
+        if not True in (self.elixir, self.sqlalchemy, self.sqlobject):
+            self.sqlalchemy = True
+
         if self.elixir:
             self.sqlalchemy = True
+            self.sqlobject = False
+        elif self.sqlalchemy:
+            self.sqlobject = False
+        if self.sqlobject:
+            self.sqlalchemy = False
+
+        if self.table_prefix:
+            self.table_prefix_always = self.table_prefix
+        else:
+            self.table_prefix_always = 'tg_'
+            self.table_prefix = ''
 
         if args:
             self.name = args[0]
@@ -186,24 +198,31 @@ class quickstart:
                 self.package = package
 
         doidentity = self.identity
-        while not doidentity:
+        while self.prompt_identity and not doidentity:
             doidentity = raw_input("Do you need Identity "
                         "(usernames/passwords) in this project? [no] ")
+
             doidentity = doidentity.lower()
+
             if not doidentity or doidentity.startswith('n'):
-                self.identity="none"
+                self.identity = "none"
                 break
+
             if doidentity.startswith("y"):
                 doidentity = True
                 break
+
             print "Please enter y(es) or n(o)."
             doidentity = None
 
         if doidentity is True:
             if self.sqlalchemy or self.elixir:
-                self.identity = "sqlalchemy"
+                self.identity = 'sqlalchemy'
             else:
-                self.identity = "sqlobject"
+                self.identity = 'sqlobject'
+        else:
+            self.identity = 'none'
+
         self.name = pkg_resources.safe_name(self.name)
 
         env = pkg_resources.Environment()
@@ -239,6 +258,8 @@ class quickstart:
         cmd_args.append("elixir=%s" % self.elixir)
         cmd_args.append("sqlobject=%s" % self.sqlobject)
         cmd_args.append("identity=%s" % self.identity)
+        cmd_args.append("table_prefix=%s" % self.table_prefix)
+        cmd_args.append("table_prefix_always=%s" % self.table_prefix_always)
         cmd_args.append("package=%s" % self.package)
         # set the exact ORM-version for the proper requirements
         # it's extracted from our own requirements, so looking
@@ -250,7 +271,7 @@ class quickstart:
             sqlalchemyversion = str(get_requirement('sqlalchemy'))
             cmd_args.append("sqlalchemyversion=%s" % sqlalchemyversion)
         if self.elixir:
-            elixirversion = str(get_requirement('future', 'elixir'))
+            elixirversion = str(get_requirement('sqlalchemy', 'elixir'))
             cmd_args.append("elixirversion=%s" % elixirversion)
 
         command.run(cmd_args)
@@ -272,54 +293,53 @@ class quickstart:
                 except OSError:
                     pass
 
-            startscript = "start-%s.py" % self.package
+            startscript = 'start-%s.py' % self.package
             if os.path.exists(startscript):
                 oldmode = os.stat(startscript).st_mode
                 os.chmod(startscript,
                         oldmode | stat.S_IXUSR)
-            sys.argv = ["setup.py", "egg_info"]
-            import imp
-            imp.load_module("setup", *imp.find_module("setup", ["."]))
+            sys.argv = ['setup.py', 'egg_info']
+            imp.load_module('setup', *imp.find_module('setup', ['.']))
 
         # dirty hack to allow "empty" dirs
-        for base, path, files in os.walk("./"):
+        for base, path, files in os.walk('./'):
             for file in files:
-                if file == "empty":
+                if file == 'empty':
                     os.remove(os.path.join(base, file))
 
 
 class update:
     "Implementation of update"
 
-    desc = "Update an existing turbogears project"
+    desc = "Update an existing TurboGears project"
     need_project = True
 
     name = None
-    templates = "turbogears"
+    templates = 'turbogears'
     identity = False
-    sqlalchemy = False
-    sqlobject = True
-    elixir = False
+    sqlalchemy = True
+    sqlobject = False
+    elixir = True
 
     def __init__(self, version):
-        parser = optparse.OptionParser(usage="%prog update [options]",
-                                       version="%prog " + version)
+        self.parser = parser = optparse.OptionParser(usage="%prog update [options]",
+            version="%prog " + version)
         parser.add_option("-s", "--sqlalchemy",
             help="use SQLAlchemy instead of SQLObject",
-            action="store_true", dest="sqlalchemy", default = False)
+            action="store_true", dest="sqlalchemy", default=False)
         parser.add_option("-e", "--elixir",
             help="use SQLAlchemy Elixir instead of SQLObject",
-            action="store_true", dest="elixir", default = False)
+            action="store_true", dest="elixir", default=False)
         parser.add_option("-o", "--sqlobject",
             help="use SQLObject instead of SQLAlchemy",
-            action="store_true", dest="sqlobject", default = True)
+            action="store_true", dest="sqlobject", default=False)
         parser.add_option("-i", "--identity",
             help="provide Identity support",
-            action="store_true", dest="identity", default = False)
+            action="store_true", dest="identity", default=False)
         parser.add_option("-t", "--templates", help="user specific templates",
             dest="templates", default=self.templates)
-        options, args = parser.parse_args()
-        self.__dict__.update(options.__dict__)
+
+        self.turbogearsversion = version
 
     def run(self):
         "Updates an existing project"
@@ -327,8 +347,26 @@ class update:
         self.package = turbogears.util.get_package_name()
         turbogears.command.base.load_project_config()
 
-        if not self.sqlalchemy:
-            if turbogears.config.get('sqlalchemy.dburi'):
+        try:
+            project_dist = pkg_resources.get_distribution(self.name)
+            project_requires = [r.project_name.lower()
+                for r in project_dist.requires()]
+            self.parser.set_defaults(
+                sqlobject = 'sqlobject' in project_requires,
+                sqlalchemy = 'sqlalchemy' in project_requires,
+                elixir = 'elixir' in project_requires)
+        except pkg_resources.DistributionNotFound:
+            print "Could not determine requirements for your application."
+            print "Please run 'python setup.py develop' to make your " + \
+                "application known to setuptools."
+
+        options, args = self.parser.parse_args()
+        self.__dict__.update(options.__dict__)
+
+        if not True in (self.elixir, self.sqlalchemy, self.sqlobject):
+            if turbogears.config.get('sqlobject.dburi'):
+                self.sqlobject = True
+            else:
                 self.sqlalchemy = True
 
         if self.elixir:
@@ -336,8 +374,8 @@ class update:
             self.sqlobject = False
         elif self.sqlalchemy:
             self.sqlobject = False
-        else:
-            self.sqlobject = True
+        if self.sqlobject:
+            self.sqlalchemy = False
 
         if not self.identity:
             if turbogears.config.get('identity.on'):
@@ -350,47 +388,55 @@ class update:
                 self.identity =  'sqlobject'
         else:
             self.identity = 'none'
+
         currentdir = os.path.basename(os.getcwd())
         if not currentdir == self.name:
-            print 'It looks like your project dir "%s" is named wrongly.' % currentdir
+            print ('It looks like your project directory "%s" is named '
+                'incorrectly.' % currentdir)
             print 'Please rename it to "%s".' % self.name
             return
 
         command = create_distro.CreateDistroCommand("update")
         cmd_args = []
-        cmd_args.append("-o../")
-        for template in self.templates.split(" "):
+        cmd_args.append('-o../')
+        for template in self.templates.split():
             cmd_args.append("--template=%s" % template)
         cmd_args.append(self.name)
-        cmd_args.append("sqlalchemy=%s" % self.sqlalchemy)
-        cmd_args.append("elixir=%s" % self.elixir)
-        cmd_args.append("sqlobject=%s" % self.sqlobject)
-        cmd_args.append("identity=%s" % self.identity)
-        cmd_args.append("package=%s" % self.package)
+        cmd_args.append('sqlalchemy=%s' % self.sqlalchemy)
+        cmd_args.append('elixir=%s' % self.elixir)
+        cmd_args.append('sqlobject=%s' % self.sqlobject)
+        cmd_args.append('identity=%s' % self.identity)
+        cmd_args.append('package=%s' % self.package)
         # set the exact ORM-version for the proper requirements
         # it's extracted from our own requirements, so looking
-        # them up must be in sync (there must be the extras_require named sqlobject/sqlalchemy)
+        # them up must be in sync (there must be the extras_require
+        # named 'sqlobject'/'sqlalchemy')
         if self.sqlobject:
             sqlobjectversion = str(get_requirement('sqlobject'))
-            cmd_args.append("sqlobjectversion=%s" % sqlobjectversion)
+            cmd_args.append('sqlobjectversion=%s' % sqlobjectversion)
 
         if self.sqlalchemy:
             sqlalchemyversion = str(get_requirement('sqlalchemy'))
-            cmd_args.append("sqlalchemyversion=%s" % sqlalchemyversion)
+            cmd_args.append('sqlalchemyversion=%s' % sqlalchemyversion)
+
+        if self.elixir:
+            elixirversion = str(get_requirement('sqlalchemy', 'elixir'))
+            cmd_args.append('elixirversion=%s' % elixirversion)
 
         command.run(cmd_args)
 
-        startscript = "start-%s.py" % self.package
+        startscript = 'start-%s.py' % self.package
         if os.path.exists(startscript):
             oldmode = os.stat(startscript).st_mode
             os.chmod(startscript,
                     oldmode | stat.S_IXUSR)
-        sys.argv = ["setup.py", "egg_info"]
+        sys.argv = ['setup.py', 'egg_info']
         import imp
-        imp.load_module("setup", *imp.find_module("setup", ["."]))
+        imp.load_module('setup', *imp.find_module('setup', ['.']))
 
         # dirty hack to allow "empty" dirs
-        for base, path, files in os.walk("./"):
+        for base, path, files in os.walk('./'):
             for file in files:
-                if file == "empty":
+                if file == 'empty':
                     os.remove(os.path.join(base, file))
+
