@@ -1,16 +1,20 @@
 """Classes and methods for TurboGears controllers."""
 
+__all__ = ['Controller', 'absolute_url',
+    'error_handler', 'exception_handler',
+    'expose', 'get_server_name', 'flash', 'redirect',
+    'Root', 'RootController', 'url', 'validate']
+
 import logging
 import urllib
 import urlparse
-import time
 import types
 
 from itertools import izip
 from inspect import isclass
 
 import cherrypy
-from cherrypy import request, response
+from cherrypy import request, response, url as cp_url
 
 from peak.rules import abstract, NoApplicableMethods
 from peak.rules.core import always_overrides, Method
@@ -21,15 +25,15 @@ from turbogears.decorator import weak_signature_decorator
 from turbogears.errorhandling import error_handler, exception_handler
 from turbogears.validators import Invalid
 
-log = logging.getLogger("turbogears.controllers")
+log = logging.getLogger('turbogears.controllers')
 
-if config.get("session_filter.on", None):
-    if config.get("session_filter.storage_type", None) == "PostgreSQL":
+if config.get('tools.sessions.on', False):
+    if config.get('tools.sessions.storage_type') == 'PostgreSQL':
         import psycopg2
         config.update(
-                {'session_filter.get_db': psycopg2.connect(
-                    psycopg2.get('sessions.postgres.dsn'))
-                    })
+            {'tools.sessions.get_db' : psycopg2.connect(
+                config.get('sessions.postgres.dsn'))
+            })
     # XXX: support for mysql/sqlite/etc here
 
 
@@ -153,7 +157,7 @@ def validate(form=None, validators=None,
 
     """
     def entangle(func):
-        if callable(form) and not hasattr(form, "validate"):
+        if callable(form) and not hasattr(form, 'validate'):
             init_form = form
         else:
             init_form = lambda self: form
@@ -163,7 +167,7 @@ def validate(form=None, validators=None,
             if hasattr(request, 'validation_state'):
                 return func(*args, **kw)
 
-            form = init_form(args and args[0] or kw["self"])
+            form = init_form(args and args[0] or kw['self'])
             args, kw = tg_util.to_kw(func, args, kw)
 
             errors = {}
@@ -221,19 +225,15 @@ first = First.make_decorator('first')
 
 def _add_rule(_expose, found_default, as_format, accept_format, template,
               rulefunc):
-    if as_format == "default":
+    if as_format == 'default':
         if found_default:
-            colon = template.find(":")
-            if colon == -1:
-                as_format = template
-            else:
-                as_format = template[:colon]
+            as_format = template.split(':', 1)[0]
         else:
             found_default = True
-    ruleparts = ['kw.get("tg_format", "default") == "%s"' % as_format]
+    ruleparts = ["kw.get('tg_format', 'default') == '%s'" % as_format]
     if accept_format:
-        ruleparts.append('(accept == "%s" and '
-            'kw.get("tg_format", "default") == "default")' % accept_format)
+        ruleparts.append("(accept == '%s'"
+            " and kw.get('tg_format', 'default') == 'default')" % accept_format)
     rule = " or ".join(ruleparts)
     log.debug("Generated rule %s", rule)
     first(_expose, rule)(rulefunc)
@@ -246,12 +246,12 @@ def _build_rules(func):
         pass
 
     if func._allow_json:
-        rule = ('allow_json and (kw.get("tg_format", None) == "json"'
-            ' or accept in ("application/json", "text/javascript"))')
+        rule = ("allow_json and (kw.get('tg_format') == 'json'"
+            " or accept in ('application/json', 'text/javascript'))")
         log.debug("Adding allow_json rule for %s: %s", func, rule)
         first(_expose, rule)(
             lambda _func, accept, allow_json, *args, **kw:
-                _execute_func(_func, "json", "json", "application/json",
+                _execute_func(_func, 'json', 'json', 'application/json',
                     False, {}, args, kw))
 
     found_default = False
@@ -262,7 +262,7 @@ def _build_rules(func):
 
 
 def expose(template=None, allow_json=None, format=None, content_type=None,
-           fragment=False, as_format="default", accept_format=None, **options):
+           fragment=False, as_format='default', accept_format=None, **options):
     """Exposes a method to the web.
 
     By putting the expose decorator on a method, you tell TurboGears that
@@ -277,16 +277,16 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
     the default that is chosen when no format is specifically asked for.
     Any other expose calls that are missing as_format and accept_format
     will have as_format implicitly set to the whatever comes before
-    the ":" in the template name (or the whole template name if there
-    is no ":". For example, <code>expose("json")</code>, if it's not
-    the default expose, will have as_format set to "json".
+    the ':' in the template name (or the whole template name if there
+    is no ':'. For example, <code>expose('json')</code>, if it's not
+    the default expose, will have as_format set to 'json'.
 
     When as_format is set, passing the same value in the tg_format
     parameter in a request will choose the options for that expose
     decorator. Similarly, accept_format will watch for matching
-    Accept headers. You can also use both. expose("json", as_format="json",
-    accept_format="application/json") will choose JSON output for either
-    case: tg_format=json as a parameter or Accept: application/json as a
+    Accept headers. You can also use both. expose('json', as_format='json',
+    accept_format='application/json') will choose JSON output for either
+    case: tg_format='json' as a parameter or Accept: application/json as a
     request header.
 
     Passing allow_json=True to an expose decorator
@@ -302,13 +302,13 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
     <a href="tests/test_expose-source.html">test_expose.py</a> suite
     for more examples.
 
-    @param template: "templateengine:dotted.reference" reference along the
+    @param template: 'templateengine:dotted.reference' reference along the
             Python path for the template and the template engine. For
-            example, "kid:foo.bar" will have Kid render the bar template in
+            example, 'kid:foo.bar' will have Kid render the bar template in
             the foo package.
     @keyparam format: format for the template engine to output (if the
             template engine can render different formats. Kid, for example,
-            can render "html", "xml" or "xhtml")
+            can render 'html', 'xml' or 'xhtml')
     @keyparam content_type: sets the content-type http header
     @keyparam allow_json: allow the function to be exposed as json
     @keyparam fragment: for template engines (like Kid) that generate
@@ -328,30 +328,29 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
     if not template:
         template = format
 
-    if format == "json" or (format is None and template is None
+    if format == 'json' or (format is None and template is None
             and (allow_json is None or allow_json)):
-        template = "json"
+        template = 'json'
         allow_json = True
 
     if content_type is None:
-        content_type = config.get("tg.content_type", None)
+        content_type = config.get('tg.content_type', None)
 
-    if config.get("tg.session.automatic_lock", None):
+    if config.get('tg.session.automatic_lock', None):
         cherrypy.session.acquire_lock()
 
     def entangle(func):
         log.debug("Exposing %s", func)
         log.debug("template: %s, format: %s, allow_json: %s, "
             "content-type: %s", template, format, allow_json, content_type)
-        if not getattr(func, "exposed", False):
+        if not getattr(func, 'exposed', False):
             def expose(func, *args, **kw):
-                request.tg_template_enginename = view.base._choose_engine(template)[2]
                 accept = request.headers.get('Accept', "").lower()
                 accept = tg_util.simplify_http_accept_header(accept)
-                if not hasattr(func, "_expose"):
+                if not hasattr(func, '_expose'):
                     _build_rules(func)
                 try:
-                    if hasattr(request, "in_transaction"):
+                    if hasattr(request, 'in_transaction'):
                         output = func._expose(func, accept, func._allow_json,
                                     *args, **kw)
                     else:
@@ -368,9 +367,9 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
                         # to wrong parameters). So we will raise a "not found"
                         # error unless a specific error status was already set
                         # (e.g. "unauthorized" was set by the identity provider):
-                        status = cherrypy.response.status
-                        if status and status // 100 == 4:
-                            raise cherrypy.HTTPError(status)
+                        status = cherrypy.request.wsgi_environ.get('identity.status')
+                        if status and str(status) >= '400':
+                            raise cherrypy.HTTPError(*str(status).split(None, 1))
                         raise cherrypy.NotFound
                     # If the error was raised elsewhere inside the controller,
                     # handle it like all other exceptions ("server error"):
@@ -378,7 +377,7 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
                 return output
             func.exposed = True
             func._ruleinfo = []
-            allow_json_from_config = config.get("tg.allow_json", False)
+            allow_json_from_config = config.get('tg.allow_json', False)
             func._allow_json = allow_json_from_config or template == 'json'
         else:
             expose = lambda func, *args, **kw: func(*args, **kw)
@@ -398,11 +397,11 @@ def expose(template=None, allow_json=None, format=None, content_type=None,
 
 def _execute_func(func, template, format, content_type, fragment, options,
                   args, kw):
-    """Call controller method and process it's output."""
+    """Call controller method and process its output."""
 
-    if config.get("tg.strict_parameters", False):
-        tg_util.remove_keys(kw, ["tg_random", "tg_format"]
-            + config.get("tg.ignore_parameters", []))
+    if config.get('tg.strict_parameters', False):
+        tg_util.remove_keys(kw, ['tg_random', 'tg_format']
+            + config.get('tg.ignore_parameters', []))
 
     else:
         # get special parameters used by upstream decorators like paginate
@@ -417,7 +416,7 @@ def _execute_func(func, template, format, content_type, fragment, options,
         # add special parameters again
         kw.update(tg_kw)
 
-    if config.get('server.environment', 'development') == 'development':
+    if config.get('environment') != 'production':
         # Only output this in development mode: If it's a field storage object,
         # this means big memory usage, and we don't want that in production
         log.debug("Calling %s with *(%s), **(%s)", func, args, kw)
@@ -435,16 +434,17 @@ def _execute_func(func, template, format, content_type, fragment, options,
 
     else:
         assert isinstance(output,
-            (basestring, dict, list, types.GeneratorType)), (
-            "Method %s.%s() returned unexpected output. Output should "
-            "be of type basestring, dict, list or generator." % (
-             args[0].__class__.__name__, func.__name__))
+            (basestring, dict, list, types.GeneratorType)) or (
+                hasattr(output, '__iter__') and hasattr(output, 'next')), (
+            "Method %s.%s() returned unexpected output."
+            " Output should be of type basestring, dict, list or generator."
+            % (args[0].__class__.__name__, func.__name__))
 
         if isinstance(output, dict):
-            template = output.pop("tg_template", template)
-            format = output.pop("tg_format", format)
+            template = output.pop('tg_template', template)
+            format = output.pop('tg_format', format)
 
-        if template and template.startswith("."):
+        if template and template.startswith('.'):
             template = func.__module__[:func.__module__.rfind('.')] + template
 
         return _process_output(output, template, format, content_type,
@@ -456,29 +456,29 @@ def flash(message):
     message = tg_util.to_utf8(message)
     if len(message) > 4000:
         log.warning('Flash message exceeding maximum cookie size!')
-    response.simple_cookie['tg_flash'] = message
-    response.simple_cookie['tg_flash']['path'] = '/'
+    response.cookie['tg_flash'] = message
+    response.cookie['tg_flash']['path'] = '/'
 
 
 def _get_flash():
-    """Retrieve the flash message (if one is set), clearing the message."""
-    request_cookie = request.simple_cookie
-    response_cookie = response.simple_cookie
+    '''Retrieve the flash message (if one is set), clearing the message.'''
+    request_cookie = request.cookie
+    response_cookie = response.cookie
 
     def clearcookie():
-        response_cookie["tg_flash"] = ""
-        response_cookie["tg_flash"]['expires'] = 0
+        response_cookie['tg_flash'] = ''
+        response_cookie['tg_flash']['expires'] = 0
         response_cookie['tg_flash']['path'] = '/'
 
-    if "tg_flash" in response_cookie:
-        message = response_cookie["tg_flash"].value
-        response_cookie.pop("tg_flash")
-        if "tg_flash" in request_cookie:
+    if 'tg_flash' in response_cookie:
+        message = response_cookie['tg_flash'].value
+        response_cookie.pop('tg_flash')
+        if 'tg_flash' in request_cookie:
             # New flash overrided old one sitting in cookie. Clear that old cookie.
             clearcookie()
-    elif "tg_flash" in request_cookie:
-        message = request_cookie.value_decode(request_cookie["tg_flash"].value)[0]
-        if "tg_flash" not in response_cookie:
+    elif 'tg_flash' in request_cookie:
+        message = request_cookie.value_decode(request_cookie['tg_flash'].value)[0]
+        if 'tg_flash' not in response_cookie:
             clearcookie()
     else:
         message = None
@@ -496,48 +496,7 @@ class Controller(object):
 
     """
 
-    msglog = logging.getLogger('cherrypy.msg')
-    msglogfunc = {0: msglog.info, 1: msglog.warning, 2: msglog.error}
-
-    @classmethod
-    def _cp_log_message(cls, msg, context = 'nocontext', severity = 0):
-        """Default method for logging messages (errors and app-specific info)"""
-        log = cls.msglogfunc[severity]
-        text = ''.join((context, ': ', msg))
-        log(text)
-
-    accesslog = logging.getLogger('turbogears.access')
-
-    @classmethod
-    def _cp_log_access(cls):
-        """Default method for logging access"""
-        # Conforms to Combined Log Format
-        # http://httpd.apache.org/docs/2.2/logs.html#combined
-        tmpl = ('%(host)s %(ident)s %(authuser)s [%(date)s] "%(request)s"'
-            ' %(status)s %(bytes)s "%(referrer)s" "%(useragent)s"')
-        try:
-            username = request.user_name
-            if username and isinstance(username, unicode):
-                # might get concatenated to non-ascii byte strings
-                username = username.encode('utf-8')
-            else:
-                username = '-'
-        except AttributeError:
-            username = '-'
-        request_date = time.strftime('%d/%b/%Y:%H:%M:%S +0000',time.gmtime())
-        request_info = {
-            'host': request.headers.get('X-Forwarded-For')
-                or request.remote_host or request.remote_addr,
-            'ident': '-',
-            'authuser': username,
-            'date': request_date,
-            'request': request.requestLine,
-            'status': response.status.split(None, 1)[0],
-            'bytes': response.headers.get('Content-Length') or '-',
-            'referrer': request.headers.get('referer', ''),
-            'useragent': request.headers.get('user-agent', ''),
-        }
-        cls.accesslog.info(tmpl, request_info)
+    is_app_root = None
 
 
 class RootController(Controller):
@@ -559,7 +518,8 @@ class ExposedDescriptor(object):
     def __get__(self, obj, cls=None):
         """Return True if object has a method for HTTP method of current request
         """
-        if cls is None: cls = obj
+        if cls is None:
+            cls = obj
         cp_methodname = cherrypy.request.method
         methodname = cp_methodname.lower()
         method = getattr(cls, methodname, None)
@@ -592,7 +552,6 @@ class RESTMethod(Controller):
                     ...
 
     """
-
     exposed = ExposedDescriptor()
 
     def __init__(self, *l, **kw):
@@ -615,26 +574,24 @@ def url(tgpath, tgparams=None, **kw):
     the second argument and/or as keyword parameters where keyword args
     overwrite entries in the dictionary.
 
-    Values which are a list or a tuple are used to create multiple
-    key-value pairs.
+    Values which are lists or tuples will create multiple key-value pairs.
 
     tgpath may also already contain a (properly escaped) query string seperated
-    by a question mark ('?'), in which case additional query params are
-    appended.
+    by a question mark, in which case additional query params are appended.
 
     """
     if not isinstance(tgpath, basestring):
         tgpath = '/'.join(list(tgpath))
     if tgpath.startswith('/'):
-        webpath = (config.get('server.webpath') or '').rstrip('/')
+        webpath = config.server.get('server.webpath', '')
         if tg_util.request_available():
-            check_app_root()
-            tgpath = request.app_root + tgpath
-            try:
-                webpath += request.wsgi_environ['SCRIPT_NAME'].rstrip('/')
-            except (AttributeError, KeyError):
-                pass
-        tgpath = webpath + tgpath
+            tgpath = cp_url(tgpath, relative='server')
+            if not request.script_name.startswith(webpath):
+                # the virtual path dispatcher is not running
+                tgpath = webpath + tgpath
+        elif webpath:
+            # the server is not running
+            tgpath = webpath + tgpath
     if tgparams is None:
         tgparams = kw
     else:
@@ -655,7 +612,7 @@ def url(tgpath, tgparams=None, **kw):
             if v is None:
                 continue
             if isinstance(v, unicode):
-                v = v.encode('utf8')
+                v = v.encode('utf-8')
             args.append((k, str(v)))
     if args:
         query_string = urllib.urlencode(args, True)
@@ -665,6 +622,7 @@ def url(tgpath, tgparams=None, **kw):
             tgpath += '?' + query_string
     return tgpath
 
+
 def get_server_name():
     """Return name of the server this application runs on.
 
@@ -681,6 +639,7 @@ def get_server_name():
             get('server.socket_port', 8080))
     return host
 
+
 def absolute_url(tgpath='/', params=None, **kw):
     """Return absolute URL (including schema and host to this server).
 
@@ -719,35 +678,6 @@ def absolute_url(tgpath='/', params=None, **kw):
         base_url = get('base_url_filter.base_url').rstrip('/')
     return '%s%s' % (base_url, url(tgpath, params, **kw))
 
-def check_app_root():
-    """Sets request.app_root if needed."""
-    if hasattr(request, 'app_root'):
-        return
-    found_root = False
-    trail = request.object_trail
-    top = len(trail) - 1
-    # compute the app_root by stepping back through the object
-    # trail and collecting up the path elements after the first
-    # root we find
-    # we can eliminate this if we find a way to use
-    # CherryPy's mounting mechanism whenever a new root
-    # is hit.
-    rootlist = []
-    for i in xrange(len(trail) - 1, -1, -1):
-        path, obj = trail[i]
-        if not found_root and isinstance(obj, RootController):
-            if i == top:
-                break
-            found_root = True
-        if found_root and i > 0:
-            rootlist.insert(0, path)
-    app_root = '/'.join(rootlist)
-    if not app_root.startswith('/'):
-        app_root = '/' + app_root
-    if app_root.endswith('/'):
-        app_root = app_root[:-1]
-    request.app_root = app_root
-
 
 def redirect(redirect_path, redirect_params=None, **kw):
     """Redirect (via cherrypy.HTTPRedirect).
@@ -758,27 +688,9 @@ def redirect(redirect_path, redirect_params=None, **kw):
     """
     if not isinstance(redirect_path, basestring):
         redirect_path = '/'.join(list(redirect_path))
-    if not redirect_path.startswith('/'):
-        path = request.path_info
-        check_app_root()
-        if path.startswith(request.app_root):
-            path = path[len(request.app_root):]
-        redirect_path = urlparse.urljoin(path, redirect_path)
-    raise cherrypy.HTTPRedirect(url(tgpath=redirect_path,
-        tgparams=redirect_params, **kw))
+    if not (redirect_path.startswith('/')
+            or redirect_path.startswith('http://')
+            or redirect_path.startswith('https://')):
+        redirect_path = urlparse.urljoin(request.path_info, redirect_path)
+    raise cherrypy.HTTPRedirect(url(redirect_path, redirect_params, **kw))
 
-
-__all__ = [
-    "Controller",
-    "absolute_url",
-    "error_handler",
-    "exception_handler",
-    "expose",
-    "get_server_name",
-    "flash",
-    "redirect",
-    "Root",
-    "RootController",
-    "url",
-    "validate",
-]
