@@ -1,12 +1,18 @@
 """Convenient access to an SQLObject or SQLAlchemy managed database."""
 
+__all__ = ['AutoConnectHub', 'bind_metadata', 'create_session',
+    'create_session_mapper', 'commit_all', 'end_all',
+    'DatabaseError', 'DatabaseConfigurationError',
+    'EndTransactions', 'get_engine', 'get_metadata', 'mapper',
+    'metadata', 'PackageHub', 'rollback_all', 'session',
+    'session_mapper', 'set_db_uri', 'so_columns', 'so_joins', 'so_to_dict']
+
 import sys
 import time
 import logging
 
 import cherrypy
 from cherrypy import request
-from cherrypy.filters.basefilter import BaseFilter
 
 try:
     import sqlalchemy, sqlalchemy.orm
@@ -30,15 +36,16 @@ from peak.rules import abstract, when, NoApplicableMethods
 from turbogears import config
 from turbogears.util import remove_keys
 
-log = logging.getLogger("turbogears.database")
-
-_using_sa = False
+log = logging.getLogger('turbogears.database')
 
 
 class DatabaseError(Exception):
-    pass
+    """TurboGears Database Error."""
+
+
 class DatabaseConfigurationError(DatabaseError):
-    pass
+    """TurboGears Database Configuration Error."""
+
 
 # Provide support for SQLAlchemy
 if sqlalchemy:
@@ -62,9 +69,9 @@ if sqlalchemy:
             return
 
         alch_args = dict()
-        for k, v in config.config.configMap["global"].items():
-            if "sqlalchemy" in k:
-                alch_args[k.split(".")[-1]] = v
+        for k, v in config.items():
+            if 'sqlalchemy' in k:
+                alch_args[k.split('.')[-1]] = v
 
         try:
             dburi = alch_args.pop('dburi')
@@ -80,9 +87,10 @@ if sqlalchemy:
         global _using_sa
         _using_sa = True
 
-        for k, v in config.config.configMap["global"].items():
-            if ".dburi" in k and 'sqlalchemy.' not in k:
-                get_metadata(k.split(".")[0]).bind = sqlalchemy.create_engine(v, **alch_args)
+        for k, v in config.items():
+            if '.dburi' in k and 'sqlalchemy.' not in k:
+                get_metadata(k.split('.')[0]).bind = sqlalchemy.create_engine(
+                    v, **alch_args)
 
     def create_session():
         """Create a session that uses the engine from thread-local metadata.
@@ -172,10 +180,14 @@ _hubs = dict() # stores the AutoConnectHubs used for each connection URI
 # Provide support for SQLObject
 if sqlobject:
     def _mysql_timestamp_converter(raw):
-        """Convert a MySQL TIMESTAMP to a floating point number representing
+        """Timestamp-converter for MySQL.
+
+        Convert a MySQL TIMESTAMP to a floating point number representing
         the seconds since the Un*x Epoch. It uses custom code the input seems
         to be the new (MySQL 4.1+) timestamp format, otherwise code from the
-        MySQLdb module is used."""
+        MySQLdb module is used.
+
+        """
         if raw[4] == '-':
             return time.mktime(time.strptime(raw, '%Y-%m-%d %H:%M:%S'))
         else:
@@ -184,14 +196,18 @@ if sqlobject:
 
 
     class AutoConnectHub(ConnectionHub):
-        """Connects to the database once per thread. The AutoConnectHub also
-        provides convenient methods for managing transactions."""
+        """Connect to the database once per thread.
+
+        The AutoConnectHub also provides convenient methods for managing
+        transactions.
+
+        """
         uri = None
         params = {}
 
         def __init__(self, uri=None, supports_transactions=True):
             if not uri:
-                uri = config.get("sqlobject.dburi")
+                uri = config.get('sqlobject.dburi')
             self.uri = uri
             self.supports_transactions = supports_transactions
             hub_registry.add(self)
@@ -204,12 +220,16 @@ if sqlobject:
             major = module_version[0]
             minor = module_version[1]
             # we can't use Decimal here because it is only available for Python 2.4
-            return (major < 1 or (major == 1 and minor < 2))
+            return major < 1 or (major == 1 and minor < 2)
 
         def _enable_timestamp_workaround(self, connection):
-            """Enable a workaround for an incompatible timestamp format change
+            """Enable timestamp-workaround for MySQL.
+
+            Enable a workaround for an incompatible timestamp format change
             in MySQL 4.1 when using an old version of MySQLdb. See trac ticket
-            #1235 - http://trac.turbogears.org/ticket/1235 for details."""
+            #1235 - http://trac.turbogears.org/ticket/1235 for details.
+
+            """
             # precondition: connection is a MySQLConnection
             import MySQLdb
             import MySQLdb.converters
@@ -218,34 +238,37 @@ if sqlobject:
                 conversions[MySQLdb.constants.FIELD_TYPE.TIMESTAMP] = \
                     _mysql_timestamp_converter
                 # There is no method to use custom keywords when using
-                # "connectionForURI" in sqlobject so we have to insert the
+                # "connectionForURI" in SQLObject so we have to insert the
                 # conversions afterwards.
-                connection.kw["conv"] = conversions
+                connection.kw['conv'] = conversions
 
         def getConnection(self):
             try:
                 conn = self.threadingLocal.connection
                 return self.begin(conn)
             except AttributeError:
-                if self.uri:
-                    conn = sqlobject.connectionForURI(self.uri)
+                uri = self.uri
+                if uri:
+                    conn = sqlobject.connectionForURI(uri)
                     # the following line effectively turns off the DBAPI connection
                     # cache. We're already holding on to a connection per thread,
-                    # and the cache causes problems with sqlite.
-                    if self.uri.startswith("sqlite"):
+                    # and the cache causes problems with SQLite.
+                    if uri.startswith('sqlite'):
                         TheURIOpener.cachedURIs = {}
-                    elif self.uri.startswith("mysql") and \
-                         config.get("turbogears.enable_mysql41_timestamp_workaround", False):
+                    elif uri.startswith('mysql') and config.get('turbogears.'
+                            'enable_mysql41_timestamp_workaround', False):
                         self._enable_timestamp_workaround(conn)
                     self.threadingLocal.connection = conn
                     return self.begin(conn)
-                raise AttributeError(
-                    "No connection has been defined for this thread "
-                    "or process")
+                raise AttributeError("No connection has been defined"
+                    " for this thread or process")
 
         def reset(self):
-            """Used for testing purposes. This drops all of the connections
-            that are being held."""
+            """Used for testing purposes.
+
+            This drops all of the connections that are being held.
+
+            """
             self.threadingLocal = threading_local()
 
         def begin(self, conn=None):
@@ -302,7 +325,9 @@ if sqlobject:
             self.threadingLocal.connection.expireAll()
 
     class PackageHub(object):
-        """Transparently proxies to an AutoConnectHub for the URI
+        """A package specific database hub.
+
+        Transparently proxies to an AutoConnectHub for the URI
         that is appropriate for this package. A package URI is
         configured via "packagename.dburi" in the TurboGears config
         settings. If there is no package DB URI configured, the
@@ -310,6 +335,7 @@ if sqlobject:
 
         The hub is not instantiated until an attempt is made to
         use the database.
+
         """
         def __init__(self, packagename):
             self.packagename = packagename
@@ -335,13 +361,13 @@ if sqlobject:
                 return getattr(self.hub.getConnection(), name)
 
         def set_hub(self):
-            dburi = config.get("%s.dburi" % self.packagename, None)
+            dburi = config.get('%s.dburi' % self.packagename, None)
             if not dburi:
-                dburi = config.get("sqlobject.dburi", None)
+                dburi = config.get('sqlobject.dburi', None)
             if not dburi:
                 raise DatabaseConfigurationError(
                     "No sqlobject database configuration found!")
-            if dburi.startswith("notrans_"):
+            if dburi.startswith('notrans_'):
                 dburi = dburi[8:]
                 trans = False
             else:
@@ -358,49 +384,57 @@ else:
     class PackageHub(object):
         pass
 
+
 def set_db_uri(dburi, package=None):
-    """Sets the database URI to use either globally or for a specific
-    package. Note that once the database is accessed, calling
-    setDBUri will have no effect.
+    """Set the database URI.
+
+    Sets the database URI to use either globally or for a specific package.
+    Note that once the database is accessed, calling it will have no effect.
 
     @param dburi: database URI to use
     @param package: package name this applies to, or None to set the default.
+
     """
     if package:
-        config.update({'global':
-            {"%s.dburi" % package : dburi}
-        })
+        config.update({'%s.dburi' % package: dburi})
     else:
-        config.update({'global':
-            {"sqlobject.dburi" : dburi}
-        })
+        config.update({'sqlobject.dburi': dburi})
+
 
 def commit_all():
     """Commit the transactions in all registered hubs (for this thread)."""
     for hub in hub_registry:
         hub.commit()
 
+
 def rollback_all():
     """Rollback the transactions in all registered hubs (for this thread)."""
     for hub in hub_registry:
         hub.rollback()
 
+
 def end_all():
     """End the transactions in all registered hubs (for this thread)."""
     for hub in hub_registry:
         hub.end()
 
+
 @abstract()
 def run_with_transaction(func, *args, **kw):
     pass
 
+
 @abstract()
 def restart_transaction(args):
     pass
 
+
+_using_sa = False
+
 def _use_sa(args=None):
     return _using_sa
 
+
 # include "args" to avoid call being pre-cached
 @when(run_with_transaction, "not _use_sa(args)")
 def so_rwt(func, *args, **kw):
@@ -424,13 +458,15 @@ def so_rwt(func, *args, **kw):
     finally:
         end_all()
 
+
 # include "args" to avoid call being pre-cached
 @when(restart_transaction, "not _use_sa(args)")
 def so_restart_transaction(args):
-    #log.debug("ReStarting SQLObject transaction")
+    # log.debug("ReStarting SQLObject transaction")
     # Disable for now for compatibility
     pass
 
+
 def dispatch_exception(exception, args, kw):
     # errorhandling import here to avoid circular imports
     from turbogears.errorhandling import dispatch_error
@@ -438,7 +474,7 @@ def dispatch_exception(exception, args, kw):
     real_func, accept, allow_json, controller = args[:4]
     args = args[4:]
     exc_type, exc_value, exc_trace = sys.exc_info()
-    remove_keys(kw, ("tg_source", "tg_errors", "tg_exceptions"))
+    remove_keys(kw, ('tg_source', 'tg_errors', 'tg_exceptions'))
     try:
         output = dispatch_error(
             controller, real_func, None, exception, *args, **kw)
@@ -448,6 +484,7 @@ def dispatch_exception(exception, args, kw):
         del exc_trace
         return output
 
+
 # include "args" to avoid call being pre-cached
 @when(run_with_transaction, "_use_sa(args)")
 def sa_rwt(func, *args, **kw):
@@ -483,6 +520,7 @@ def sa_rwt(func, *args, **kw):
         session.close()
     return retval
 
+
 # include "args" to avoid call being pre-cached
 @when(restart_transaction, "_use_sa(args)")
 def sa_restart_transaction(args):
@@ -495,6 +533,7 @@ def sa_restart_transaction(args):
     session.close()
     request.sa_transaction = session.begin()
 
+
 def sa_transaction_active():
     """Check whether SA transaction is still active."""
     try:
@@ -509,6 +548,7 @@ def sa_transaction_active():
             except AttributeError:
                 return False
 
+
 def so_to_dict(sqlobj):
     """Convert SQLObject to a dictionary based on columns."""
     d = {}
@@ -522,6 +562,7 @@ def so_to_dict(sqlobj):
         d.pop('childName')
     return d
 
+
 def so_columns(sqlclass, columns=None):
     """Return a dict with all columns from a SQLObject.
 
@@ -536,6 +577,7 @@ def so_columns(sqlclass, columns=None):
         so_columns(sqlclass.__base__, columns)
     return columns
 
+
 def so_joins(sqlclass, joins=None):
     """Return a list with all joins from a SQLObject.
 
@@ -549,20 +591,13 @@ def so_joins(sqlclass, joins=None):
         so_joins(sqlclass.__base__, joins)
     return joins
 
-class EndTransactionsFilter(BaseFilter):
-    def on_end_resource(self):
-        if _use_sa():
-            try:
-                session.expunge_all()
-            except AttributeError: # SQLAlchemy < 0.5.1
-                session.clear()
-        else:
-            end_all()
 
-__all__ = ["AutoConnectHub", "bind_metadata", "create_session",
-           "create_session_mapper", "commit_all", "end_all",
-           "DatabaseError", "DatabaseConfigurationError",
-           "EndTransactionsFilter", "get_engine", "get_metadata", "mapper",
-           "metadata", "PackageHub", "rollback_all", "session",
-           "session_mapper", "set_db_uri", "so_columns", "so_joins",
-           "so_to_dict"]
+def EndTransactions():
+    if _use_sa():
+        try:
+            session.expunge_all()
+        except AttributeError: # SQLAlchemy < 0.5.1
+            session.clear()
+    else:
+        end_all()
+
