@@ -1,3 +1,9 @@
+"""Error handling functions."""
+
+__all__ = ['dispatch_error', 'dispatch_error_adaptor', 'try_call',
+   'run_with_errors', 'default', 'register_handler', 'FailsafeSchema',
+   'dispatch_failsafe', 'error_handler', 'exception_handler']
+
 import sys
 from itertools import izip, islice
 from inspect import getargspec
@@ -5,8 +11,8 @@ from inspect import getargspec
 import cherrypy
 from peak.rules import abstract, when, around, NoApplicableMethods
 
-from turbogears.util import inject_args, adapt_call, call_on_stack, has_arg, \
-    remove_keys, Enum
+from turbogears.util import (inject_args, adapt_call, call_on_stack, has_arg,
+    remove_keys, Enum)
 from turbogears.decorator import func_id
 
 
@@ -60,8 +66,8 @@ def dispatch_error_adaptor(func):
     def adaptor(controller, tg_source,
             tg_errors, tg_exceptions, *args, **kw):
         tg_format = kw.pop('tg_format', None)
-        args, kw = inject_args(func, {"tg_source": tg_source,
-            "tg_errors": tg_errors, "tg_exceptions": tg_exceptions},
+        args, kw = inject_args(func, {'tg_source': tg_source,
+            'tg_errors': tg_errors, 'tg_exceptions': tg_exceptions},
                 args, kw, 1)
         args, kw = adapt_call(func, args, kw, 1)
         if tg_format is not None:
@@ -76,16 +82,16 @@ def try_call(func, self, *args, **kw):
     try:
         return func(self, *args, **kw)
     except Exception, e:
-        if isinstance(e, cherrypy.HTTPRedirect) or \
-                call_on_stack("dispatch_error",
-                    {"tg_source": func, "tg_exception": e}, 4):
+        if (isinstance(e, cherrypy.HTTPRedirect)
+                or call_on_stack('dispatch_error',
+                    {'tg_source': func, 'tg_exception': e}, 4)):
             raise
         else:
             exc_type, exc_value, exc_trace = sys.exc_info()
-            remove_keys(kw, ("tg_source", "tg_errors", "tg_exceptions"))
+            remove_keys(kw, ('tg_source', 'tg_errors', 'tg_exceptions'))
             if 'tg_format' in cherrypy.request.params:
                 kw['tg_format'] = 'json'
-            if getattr(cherrypy.request, "in_transaction", None):
+            if getattr(cherrypy.request, 'in_transaction', None):
                 restart_transaction(1)
             try:
                 output = dispatch_error(self, func, None, e, *args, **kw)
@@ -98,7 +104,7 @@ def try_call(func, self, *args, **kw):
 def run_with_errors(errors, func, self, *args, **kw):
     """Branch execution depending on presence of errors."""
     if errors:
-        if hasattr(self, "validation_error"):
+        if hasattr(self, 'validation_error'):
             import warnings
             warnings.warn(
                 "Use decorator error_handler() on per-method base "
@@ -106,7 +112,7 @@ def run_with_errors(errors, func, self, *args, **kw):
                 DeprecationWarning, 2)
             return self.validation_error(func.__name__, kw, errors)
         else:
-            remove_keys(kw, ("tg_source", "tg_errors", "tg_exceptions"))
+            remove_keys(kw, ('tg_source', 'tg_errors', 'tg_exceptions'))
             if 'tg_format' in cherrypy.request.params:
                 kw['tg_format'] = 'json'
             try:
@@ -147,11 +153,11 @@ def bind_rules(pre_rules):
         return register_handler(handler, new_rules)
     return registrant
 
-error_handler = bind_rules("tg_errors")
-exception_handler = bind_rules("tg_exceptions")
+error_handler = bind_rules('tg_errors')
+exception_handler = bind_rules('tg_exceptions')
 
 
-FailsafeSchema = Enum("none", "values", "map_errors", "defaults")
+FailsafeSchema = Enum('none', 'values', 'map_errors', 'defaults')
 
 def dispatch_failsafe(schema, values, errors, source, kw):
     """Dispatch fail-safe mechanism for failed inputs."""
@@ -186,13 +192,10 @@ def _failsafe_map_errors(schema, values, errors, source, kw):
 def _failsafe_defaults(schema, values, errors, source, kw):
     """Map erroneous inputs to method defaults."""
     argnames, defaultvals = getargspec(source)[::3]
-    defaults = dict(izip(islice(argnames, len(argnames) - len(defaultvals),
-                         None), defaultvals))
+    defaults = dict(izip(islice(
+        argnames, len(argnames) - len(defaultvals), None), defaultvals))
     for key in errors:
         if key in defaults:
             kw[key] = defaults[key]
     return kw
 
-__all__ = ["dispatch_error", "dispatch_error_adaptor", "try_call",
-           "run_with_errors", "default", "register_handler", "FailsafeSchema",
-           "dispatch_failsafe", "error_handler", "exception_handler"]
