@@ -279,43 +279,6 @@ class SqlObjectIdentityProvider(object):
         return SqlObjectIdentity(user=user)
 
 
-class TG_VisitIdentity(SQLObject):
-    """A visit to your website."""
-
-    class sqlmeta:
-        table = 'visit_identity'
-
-    visit_key = StringCol(length=40, alternateID=True,
-        alternateMethodName='by_visit_key')
-    user_id = IntCol()
-
-
-class TG_Group(SQLObject):
-    """An ultra-simple group definition."""
-
-    group_name = UnicodeCol(length=16, alternateID=True,
-        alternateMethodName='by_group_name')
-    display_name = UnicodeCol(length=255)
-    created = DateTimeCol(default=datetime.now)
-
-    # collection of all users belonging to this group
-    users = RelatedJoin('TG_User', intermediateTable='user_group',
-        joinColumn='group_id', otherColumn='user_id')
-
-    # collection of all permissions for this group
-    permissions = RelatedJoin('TG_Permission', joinColumn='group_id',
-        intermediateTable='group_permission',
-        otherColumn='permission_id')
-
-@jsonify.when('isinstance(obj, TG_Group)')
-def jsonify_group(obj):
-    """Convert group to JSON."""
-    result = jsonify_sqlobject(obj)
-    result['users'] = [u.user_name for u in obj.users]
-    result['permissions'] = [p.permission_name for p in obj.permissions]
-    return result
-
-
 class TG_User(SQLObject):
     """Reasonably basic User definition."""
 
@@ -360,12 +323,38 @@ class TG_User(SQLObject):
 def jsonify_user(obj):
     """Convert user to JSON."""
     result = jsonify_sqlobject(obj)
-    del result['password']
+    result.pop('password', None)
     result['groups'] = [g.group_name for g in obj.groups]
     result['permissions'] = [p.permission_name for p in obj.permissions]
     return result
 
 
+class TG_Group(SQLObject):
+    """An ultra-simple group definition."""
+
+    group_name = UnicodeCol(length=16, alternateID=True,
+        alternateMethodName='by_group_name')
+    display_name = UnicodeCol(length=255)
+    created = DateTimeCol(default=datetime.now)
+
+    # collection of all users belonging to this group
+    users = RelatedJoin('TG_User', intermediateTable='user_group',
+        joinColumn='group_id', otherColumn='user_id')
+
+    # collection of all permissions for this group
+    permissions = RelatedJoin('TG_Permission', joinColumn='group_id',
+        intermediateTable='group_permission',
+        otherColumn='permission_id')
+
+@jsonify.when('isinstance(obj, TG_Group)')
+def jsonify_group(obj):
+    """Convert group to JSON."""
+    result = jsonify_sqlobject(obj)
+    result['users'] = [u.user_name for u in obj.users]
+    result['permissions'] = [p.permission_name for p in obj.permissions]
+    return result
+
+
 class TG_Permission(SQLObject):
     """Permissions for a given group."""
 
@@ -387,6 +376,17 @@ def jsonify_permission(obj):
     return result
 
 
+class TG_VisitIdentity(SQLObject):
+    """A visit to your website."""
+
+    class sqlmeta:
+        table = 'visit_identity'
+
+    visit_key = StringCol(length=40, alternateID=True,
+        alternateMethodName='by_visit_key')
+    user_id = IntCol()
+
+
 def encrypt_password(cleartext_password):
     """Encrypt given cleartext password."""
     try:
