@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+
 """\
 Front-to-back rapid web development
 ===================================
@@ -29,7 +30,7 @@ problem.
     http://svn.turbogears.org/trunk#egg=turbogears-dev
 """
 
-version = "1.1.2"
+version = "1.5"
 description = "Front-to-back, open-source, rapid web development framework"
 long_description = __doc__
 author = "Kevin Dangoor"
@@ -37,7 +38,8 @@ email = "dangoor+turbogears@gmail.com"
 maintainer = "TurboGears Release Team"
 maintainer_email = "turbogears@googlegroups.com"
 url = "http://www.turbogears.org/"
-download_url = "http://www.turbogears.org/download/filelist.html"
-dependency_links = ["http://files.turbogears.org/eggs/"]
-copyright = "Copyright 2005 - 2010 Kevin Dangoor and contributors"
+download_url = "http://www.turbogears.org/%s/downloads/%s/index" % (
+    '.'.join(version.split('.', 2)[:2]), version)
+dependency_links = [download_url]
+copyright = "Copyright 2005 - 2011 Kevin Dangoor and contributors"
 license = "MIT"
