@@ -1,7 +1,11 @@
 # -*- encoding: utf-8 -*-
 
+try:
+    import json
+except ImportError: # Python < 2.6
+    import simplejson as json
+
 import cherrypy
-import simplejson
 
 from turbogears import expose, testutil
 from turbogears.controllers import RESTMethod
@@ -13,7 +17,7 @@ class UserController(object):
 
     class default(RESTMethod):
 
-        @expose(format='json')
+        @expose('json')
         def get(self, user_name=None):
             if user_name is None:
                 raise cherrypy.NotFound
@@ -30,7 +34,7 @@ class UserController(object):
             if cherrypy.request.headers['Content-Type'] != 'application/json':
                 raise cherrypy.HTTPError(
                          415, 'JSON is the only supported format')
-            user_details = simplejson.load(cherrypy.request.body)
+            user_details = json.load(cherrypy.request.body)
             __user_registry__[user_name] = user_details
             cherrypy.response.status = '204 No Content'
 
@@ -39,7 +43,7 @@ class RootController(object):
 
     class users(RESTMethod):
 
-        @expose(format='json')
+        @expose('json')
         def get(self):
             """Return a json formatted list of users"""
             return dict(users=[dict(uri='/'.join(['/user', user_name]),
@@ -54,7 +58,7 @@ class RootController(object):
             if cherrypy.request.headers['Content-Type'] != 'application/json':
                 raise cherrypy.HTTPError(
                           415, 'JSON is the only supported format')
-            user_details = simplejson.load(cherrypy.request.body)
+            user_details = json.load(cherrypy.request.body)
             user_name = user_details.pop('user_name')
             __user_registry__[user_name] = user_details
             cherrypy.response.status = '201 Created'
@@ -83,7 +87,7 @@ class TestREST(testutil.TGTest):
 
     def test_post(self):
         user = dict(user_name='psr', first_name=u'Peter', last_name=u'Russell')
-        resp = self.app.post('/users', simplejson.dumps(user),
+        resp = self.app.post('/users', json.dumps(user),
                              {'Content-Type': 'application/json'})
         assert __user_registry__['psr'] == dict(first_name=u'Peter',
                                                 last_name=u'Russell')
@@ -98,14 +102,10 @@ class TestREST(testutil.TGTest):
         __user_registry__['psr'] = dict(first_name=u'Peter',
                                         last_name=u'André')
         user = dict(first_name=u'Peter', last_name=u'Russell')
-        self.app.put('/user/psr', simplejson.dumps(user),
+        self.app.put('/user/psr', json.dumps(user),
                      headers={'Content-Type': 'application/json'})
         assert __user_registry__['psr']['last_name'] == u'Russell'
 
     def test_unsupported_method(self):
-        """Check that we receive a 405 error on deletes."""
-        # Actually this resource doesn't exist, and so should raise a 404.
-        # It's not obvious how to fix this, perhaps by using a different
-        # approach to resources than the default method?
-        self.app.delete('/user/psr', status=405)
-
+        """Check that we receive a 404 error on deletes."""
+        self.app.delete('/user/psr', status=404)
