@@ -1,7 +1,6 @@
 
 import sys
 from StringIO import StringIO
-from warnings import simplefilter, resetwarnings
 
 from turbogears import config, util
 
@@ -39,6 +38,68 @@ def test_deprecated():
     assert 'this is old' not in output, output
 
 
+def test_missing_dependency_error():
+    msg = util.missing_dependency_error('foo')
+    assert isinstance(msg, str)
+    assert 'you need to install' in msg
+    assert 'requires the foo package' in msg
+
+
+def test_bunch():
+    bunch = util.Bunch(foo='bar')
+    assert bunch.foo == 'bar'
+    del bunch.foo
+    try:
+        bunch.foo
+    except AttributeError:
+        None
+    else:
+        assert False, 'foo attribute should have been deleted'
+    bunch.foo = 'bar'
+    assert bunch.foo == 'bar'
+    assert repr(bunch) == "Bunch(foo='bar')"
+
+
+def test_enum():
+    enum = util.Enum('apples', 'cherries', 'pears')
+    assert len(enum) == 3
+    assert len([n for n in enum]) == 3
+    assert enum[0] != enum[1]
+    assert enum[1] != enum[2]
+    assert enum[1] == enum[1]
+    try:
+        if enum[1] == 'cherries':
+            raise ValueError
+    except TypeError:
+        pass
+    else:
+        assert False, 'enum should not be comparable with string'
+    enum2 = util.Enum('bananas', 'cranberries', 'oranges')
+    assert enum is not enum2
+    try:
+        if enum[1] == enum2[1]:
+            raise ValueError
+    except TypeError:
+        pass
+    else:
+        assert False, 'enum should not be comparable with enum2'
+
+
+def test_setlike():
+    s = util.setlike((1, 2, 3))
+    assert len(s) == 3
+    assert list(s) == [1, 2, 3]
+    s.add(2)
+    assert len(s) == 3
+    assert list(s) == [1, 2, 3]
+    s.add(4)
+    assert len(s) == 4
+    assert list(s) == [1, 2, 3, 4]
+    s.add_all((4, 5, 6))
+    assert len(s) == 6
+    assert list(s) == [1, 2, 3, 4, 5, 6]
+
+
 def test_adapt_call():
     adapt = util.adapt_call
 
@@ -158,43 +219,6 @@ def test_arg_index():
     assert util.arg_index(fun, 'z') == 3
 
 
-def test_pop_from_nested_dict():
-    pop = util.pop_from_nested_dict
-    params = {'likes': {
-     'fruits': {'bananas': 1, 'apples': 2, 'peaches': 3},
-     'languages': {'python': 4, 'c#': 5, 'java': 6, 'fortan': 7}},
-     'dislikes': {'nested': {'structures': 8}},
-     'submit': {None: 9, 'x': 10, 'y': 11},
-     'more': {'submit': {None: 12}},
-     'user_name': 'homer', 'password': 'doh'
-     }
-    assert pop(params, 'user_name') == 'homer'
-    assert 'user_name' not in params
-    assert pop(params, ['password']) == 'doh'
-    assert 'password' not in params
-    assert pop(params, 'fruits') is None
-    assert pop(params, 'likes.fruits') is None
-    assert pop(params, 'likes.fruits.apples') == 2
-    assert 'likes' in params
-    assert 'fruits' in params['likes']
-    assert 'apples' not in params['likes']['fruits']
-    assert 'peaches' in params['likes']['fruits']
-    assert pop(params, 'likes.fruits.bananas') == 1
-    assert pop(params, ['likes', 'fruits', 'peaches']) == 3
-    assert 'likes' in params
-    assert 'fruits' not in params['likes']
-    assert pop(params, 'dislikes.nested') is None
-    assert pop(params, 'dislikes.nested.structures') == 8
-    assert 'dislikes' not in params
-    assert pop(params, 'submit') == 9
-    assert 'submit' in params
-    assert params['submit'] == {'x': 10, 'y': 11}
-    assert pop(params, 'more') is None
-    assert pop(params, 'more.submit.buttons') is None
-    assert pop(params, 'more.submit') == 12
-    assert 'more' not in params
-
-
 def test_parse_http_accept_header():
     t = util.parse_http_accept_header
     assert t(None) == []
