@@ -6,15 +6,17 @@ import time
 import shutil
 import codecs
 
-import pygettext
-import msgfmt
-import catalog
-
-import cherrypy
-from cherrypy.lib.cptools import serveFile
-
 import turbogears
 from turbogears import controllers, expose, i18n
+from turbogears.i18n.pygettext import pygettext
+from turbogears.i18n.pygettext import msgfmt
+from turbogears.i18n.pygettext import catalog
+
+import cherrypy
+from cherrypy.lib import static
+
+# this is a list of supported file extensions.
+supported_exts = ['.py', '.kid', '.tmpl', '.html', '.mak']
 
 
 class Internationalization(controllers.RootController):
@@ -25,12 +27,12 @@ class Internationalization(controllers.RootController):
 
     """
 
-    __label__ = "admi18n"
-    __version__ = "0.1"
-    __author__ = "Ronald Jaramillo"
-    __email__ = "ronald@checkandshare.com"
-    __copyright__ = "Copyright 2005 Ronald Jaramillo"
-    __license__ = "MIT"
+    __label__ = 'admi18n'
+    __version__ = '0.1'
+    __author__ = 'Ronald Jaramillo'
+    __email__ = 'ronald@checkandshare.com'
+    __copyright__ = 'Copyright 2005 Ronald Jaramillo'
+    __license__ = 'MIT'
 
     baseTemplate = 'turbogears.toolbox.admi18n'
     languages = None
@@ -104,7 +106,7 @@ class Internationalization(controllers.RootController):
         dest = os.path.join(path, 'messages.po')
         shutil.copy(src, dest)
 
-    [expose(format='json')]
+    @expose('json')
     def po_upload(self, myFile, code):
         path = os.path.join(self.locales_directory(),
                 code, 'LC_MESSAGES', 'messages.po')
@@ -126,14 +128,14 @@ class Internationalization(controllers.RootController):
                     from_lang, to_lang, msg_id)
             catalog.update(path, msg_id, translated)
 
-    [expose(format='json')]
+    @expose('json')
     def update_catalog(self, code, msg_id, msg_text):
         path = os.path.join(self.locales_directory(),
                 code, 'LC_MESSAGES', 'messages.po')
         catalog.update(path, msg_id, msg_text)
         return 'ok'
 
-    [expose(template='%s.po_view' % baseTemplate)]
+    @expose('%s.po_view' % baseTemplate)
     def po_view(self, code, sort_by=None, dir=None,
             from_lang=None, to_lang=None, **kargs):
         visible_checkbox = False
@@ -145,7 +147,7 @@ class Internationalization(controllers.RootController):
         return dict(code=code, catalog=catalog.items(path, sort_by, dir),
                 visible_checkbox=visible_checkbox)
 
-    [expose(template='%s.language' % baseTemplate)]
+    @expose('%s.language' % baseTemplate)
     def language(self, code):
         path = os.path.join(self.locales_directory(),
             code, 'LC_MESSAGES', 'messages.po')
@@ -156,11 +158,11 @@ class Internationalization(controllers.RootController):
             language=self.language_for_code(code),
             po_message_file=po_message_file)
 
-    [expose(format='json')]
+    @expose('json')
     def language_list(self):
         return dict(languages=self.get_languages())
 
-    [expose(template='%s.languageManagement' % baseTemplate)]
+    @expose('%s.languageManagement' % baseTemplate)
     def language_management(self, add=None, rem=None, compile=None, merge=None):
         if add:
             self.add_locale(add)
@@ -245,15 +247,17 @@ class Internationalization(controllers.RootController):
 
             namelist.sort()
             for name in namelist[:]:
-                if name.startswith('.') or \
-                        name in ['static', 'sqlobject-history']:
+                if (name.startswith('.')
+                        or name in ['static', 'sqlobject-history']):
                     namelist.remove(name)
                     continue
+
                 p = os.path.join(dirpath, name)
-                if os.path.isfile(p) and \
-                        os.path.splitext(name)[-1] in ['.py','.kid','.tmpl']:
+                if (os.path.isfile(p)
+                        and os.path.splitext(name)[-1] in supported_exts):
                     slot2.append(dict(dir=dirpath, file_name=name,
                         path=p, isdir=os.path.isdir(p), level=level+1))
+
             # decide if current directory (and ancestors) should be visible
             visibility[dirpath] = bool(slot2)
             if slot2:
@@ -263,7 +267,7 @@ class Internationalization(controllers.RootController):
 
         os.path.walk(p, collect_files, fl)
         return [x for x in turbogears.util.flatten_sequence(fl)
-                if not x["isdir"] or visibility[x["path"]]]
+                if not x['isdir'] or visibility[x['path']]]
 
     def collect_string_for_files(self, files):
         if not files:
@@ -283,8 +287,8 @@ class Internationalization(controllers.RootController):
         locales = self.locales_directory()
         filename = os.path.join(locales, 'messages.pot')
         try:
-            os.rename(pot, filename)
-        except OSError, e:
+            shutil.copyfile(pot, filename)
+        except IOError, e:
             print e
 
     def pot_message_file(self):
@@ -297,7 +301,7 @@ class Internationalization(controllers.RootController):
             modified=time.ctime(os.path.getmtime(pot)),
             size=os.path.getsize(pot))
 
-    [expose()]
+    @expose()
     def lang_file(self, code):
         # serve static file, the code can be pot or a lang code
         locales = self.locales_directory()
@@ -309,9 +313,9 @@ class Internationalization(controllers.RootController):
             path = os.path.join(path, 'messages.po')
         if 'If-Modified-Since' in cherrypy.request.headers:
             del cherrypy.request.headers['If-Modified-Since'] # see ticket #879
-        return serveFile(path, "application/x-download", "attachment")
+        return static.serve_file(path, 'application/x-download', 'attachment')
 
-    [expose(template='%s.stringCollection' % baseTemplate)]
+    @expose('%s.stringCollection' % baseTemplate)
     def string_collection(self, files=[]):
         if files:
             if type(files) != type([]):
@@ -320,6 +324,6 @@ class Internationalization(controllers.RootController):
         return dict(project_files=self.project_files(),
             pot_message_file=self.pot_message_file())
 
-    [expose(template='%s.internationalization' % baseTemplate)]
+    @expose('%s.internationalization' % baseTemplate)
     def index(self):
         return dict()
