@@ -1,14 +1,14 @@
 """CatWalk - model browser for TurboGears"""
 
-__version__ = "0.9.4"
-__author__ = "Ronald Jaramillo"
-__email__ = "ronald@checkandhsare.com"
-__copyright__ = "Copyright 2005 Ronald Jaramillo"
-__license__ = "MIT"
+__version__ = '0.9.4'
+__author__ = 'Ronald Jaramillo'
+__email__ = 'ronald@checkandhsare.com'
+__copyright__ = 'Copyright 2005 Ronald Jaramillo'
+__license__ = 'MIT'
 
-from browse import Browse
 import cPickle as pickle
 import datetime
+import decimal
 import os
 import re
 import socket
@@ -27,6 +27,7 @@ except ImportError:
 import turbogears
 from turbogears import config, expose, identity
 
+from browse import Browse
 
 date_parser = re.compile(r"""^
     (?P<year>\d{4,4})
@@ -94,12 +95,12 @@ class CatWalk(turbogears.controllers.Controller):
 
     """
 
-    __label__ = "CatWalk"
-    __version__ = "0.9"
-    __author__ = "Ronald Jaramillo"
-    __email__ = "ronald@checkandshare.com"
-    __copyright__ = "Copyright 2005 Ronald Jaramillo"
-    __license__ = "MIT"
+    __label__ = 'CatWalk'
+    __version__ ='"0.9'
+    __author__ = 'Ronald Jaramillo'
+    __email__ = 'ronald@checkandshare.com'
+    __copyright__ = 'Copyright 2005 Ronald Jaramillo'
+    __license__ = 'MIT'
     browse = Browse()
     need_project = True
     icon = "/tg_static/images/catwalk.png"
@@ -114,34 +115,33 @@ class CatWalk(turbogears.controllers.Controller):
 
         try:
             if not sqlobject:
-                raise ImportError, "The SQLObject package is not installed."
+                raise ImportError("The SQLObject package is not installed.")
             if not model:
                 model = turbogears.util.get_model()
             if not model:
-                raise ImportError, ("No SQLObject model found.\n"
+                raise ImportError("No SQLObject model found.\n"
                     "If you are mounting CatWalk to your controller,\n"
                     "remember to import your model and pass a reference to it.")
             self.model = model
             if not self.models():
-                raise ImportError, "The SQLObject model is empty."
+                raise ImportError("The SQLObject model is empty.")
             try:
                 self._connection = model.hub
             except Exception:
                 self._connection = sqlobject.sqlhub
         except Exception, e:
-            raise ImportError, (
+            raise ImportError(
                 "CatWalk failed to load your model file.\n" + str(e))
         self.browse.catwalk = self
-        turbogears.config.update({'log_debug_info_filter.on': False})
         self.register_static_directory()
 
     def register_static_directory(self):
         static_directory = pkg_resources.resource_filename(__name__, 'static')
         turbogears.config.update({'/tg_toolbox/catwalk': {
-            'static_filter.on': True,
-            'static_filter.dir': static_directory}})
+            'tools.staticdir.on' : True,
+            'tools.staticdir.dir': static_directory}})
 
-    @expose(format="json")
+    @expose('json')
     def error(self, msg=''):
         """Generic error handler for json replies."""
         return dict(error=msg)
@@ -182,7 +182,8 @@ class CatWalk(turbogears.controllers.Controller):
         @type column: dict
 
         """
-        if column.get('type', '') == 'SOSingleJoin':
+        column_type = column.get('type', '')
+        if column_type == 'SOSingleJoin':
             try:
                 subject =  getattr(row, column['joinMethodName'])
                 value = '%s' % getattr(subject, column['labelColumn'])
@@ -190,21 +191,23 @@ class CatWalk(turbogears.controllers.Controller):
                 return {'column': column['columnName'],
                     'value': 'None', 'id': '0'}
             return {'column': column['columnName'], 'value': value}
-        elif column.get('type','') in ('SORelatedJoin', 'SOSQLRelatedJoin'):
+        elif column_type in ('SORelatedJoin', 'SOSQLRelatedJoin'):
             return self.related_join_count(row, column)
-        elif column.get('type', '') in ('SOMultipleJoin', 'SOSQLMultipleJoin'):
+        elif column_type in ('SOMultipleJoin', 'SOSQLMultipleJoin'):
             return self.multiple_join_count(row, column)
-        elif column.get('type','') == 'SOForeignKey':
+        elif column_type == 'SOForeignKey':
             return self.object_field_for_foreign_key(row, column)
-        elif column.get('type', '') == 'SOStringCol':
+        elif column_type == 'SOStringCol':
             value = getattr(row, column['columnName'])
             value = self.encode_label(value)
             return {'column': column['columnName'], 'value': value}
         else:
-            try:
-                value = u'%s' % getattr(row, column['columnName'])
-            except UnicodeDecodeError:
-                value = unicode(getattr(row, column['columnName']), 'UTF-8')
+            value = getattr(row, column['columnName'])
+            if value is not None:
+                try:
+                    value = u'%s' % value
+                except UnicodeDecodeError:
+                    value = unicode(value, 'UTF-8')
             return {'column': column['columnName'], 'value': value}
 
     def multiple_join_count(self, row, column):
@@ -264,70 +267,75 @@ class CatWalk(turbogears.controllers.Controller):
         """Loop trough the columns and extract the values from the dictionary.
 
         @param cols: column list
-        @param values: dict of submited values
+        @param values: dict of submitted values
 
         """
         params = {}
         for col in cols:
             column_name = col['columnName']
-            if values.has_key(column_name):
-                if col['type'] == 'SODateTimeCol':
-                    dt = values[column_name]
-                    try:
-                        b = parse_datetime('%sZ' % dt.replace(' ', 'T'))
-                    except ValueError:
-                        b  = None
-                    values[column_name] = b
-                elif col['type'] == 'SOBoolCol':
-                    try:
-                        b = bool(int(values[column_name]))
-                    except ValueError:
-                        b = False
-                    values[column_name] = b
-                elif col['type'] == 'SOFloatCol':
-                    try:
-                        b = float(values[column_name])
-                    except ValueError:
-                        b = 0.0
-                    values[column_name] = b
-                elif col['type'] == 'SOIntCol':
-                    try:
-                        b = int(values[column_name])
-                    except ValueError:
-                        b = 0
-                    values[column_name] = b
-                elif col['type'] == 'SOForeignKey':
-                    self.extract_foreign_key(values, column_name)
-                elif col['type'] in ('SODecimalCol','SOCurrencyCol'):
-                    self.extract_decimal_value(values, column_name)
-
-                if values.has_key(column_name):
-                    params[column_name] = values[column_name]
+            if column_name not in values:
+                continue
+            value = values[column_name]
+            not_none = col['notNone']
+            column_type = col['type']
+            if column_type == 'SODateTimeCol':
+                try:
+                    value = parse_datetime('%sZ' % value.replace(' ', 'T'))
+                except ValueError:
+                    value  = None
+            elif column_type == 'SOBoolCol':
+                try:
+                    value= bool(int(value))
+                except ValueError:
+                    if not_none:
+                        value = False
+                    else:
+                        value = None
+            elif column_type == 'SOFloatCol':
+                try:
+                    value = float(value)
+                except ValueError:
+                    if not_none:
+                        value = 0.0
+                    else:
+                        value = None
+            elif column_type == 'SOIntCol':
+                try:
+                    value = int(value)
+                except ValueError:
+                    if not_none:
+                        value = 0
+                    else:
+                        value = None
+            elif column_type in ('SODecimalCol','SOCurrencyCol'):
+                value = self.extract_decimal_value(value, not_none)
+            elif column_type == 'SOForeignKey':
+                value = self.extract_foreign_key(value, not_none)
+            else:
+                if not (value or not_none):
+                    value = None
+            params[column_name] = values[column_name] = value
         return params
 
-    def extract_foreign_key(self, values, column_name):
-        if values[column_name] == '__default_none__':
-            values[column_name] = None
-        else:
-            try:
-                b = int(values[column_name])
-            except ValueError:
-                b = 0
-            values[column_name] = b
-
-    def extract_decimal_value(self, values, column_name):
+    def extract_foreign_key(self, value, not_none):
+        if value == '__default_none__':
+            return value
         try:
-            import decimal
-            try:
-                b = decimal.Decimal(values[column_name])
-            except (TypeError, ValueError, decimal.InvalidOperation):
-                b = decimal.Decimal('0.0')
-        except ImportError:
-            try:
-                b = float(values[column_name])
-            except ValueError:
-                b = 0.0
-        values[column_name] = b
+            return int(value)
+        except ValueError:
+            if not_none:
+                return 0
+            else:
+                return None
+
+    def extract_decimal_value(self, value, not_none):
+        try:
+            return decimal.Decimal(value)
+        except (TypeError, ValueError, decimal.InvalidOperation):
+            if not_none:
+                return decimal.Decimal('0.0')
+            else:
+                return None
 
     def object_instances(self, object_name, start=0):
         """Return dictionary containing all instances for the requested object.
@@ -476,12 +484,18 @@ class CatWalk(turbogears.controllers.Controller):
             return d.split()[0]
         return ''
 
+    def column_not_none(self, column):
+        try:
+            return column.notNone
+        except AttributeError:
+            return False
+
     def get_column_properties(self, column_name, column):
         """Return a dictionary containing the column properties.
 
         Depending on the column type the properties returned could be:
         type, title, join (otherClassName), joinMethodName,
-        length, varchar,labelColumn,opetions
+        length, varchar, labelColumn, options
 
         @param column_name: name of the column
         @type column_name: string
@@ -492,6 +506,7 @@ class CatWalk(turbogears.controllers.Controller):
             'columnName': column_name}
         props['title'] = self.column_title(column)
         props['default'] = self.column_default(column, props['type'])
+        props['notNone'] = self.column_not_none(column)
         if props['type'] == 'SOEnumCol':
             props['options'] = column.enumValues
         if props['type'] in ('SOMultipleJoin', 'SOSQLMultipleJoin',
@@ -581,7 +596,7 @@ class CatWalk(turbogears.controllers.Controller):
 
         By default this is located in a directory named 'catwalk-session'
         beneath your application's package directory or, if the package name
-        can not be determined, below the ccurrent directory.
+        can not be determined, below the current directory.
 
         The directory must be writable by the server and will be created if it
         does not exist. You can specify a different directory if you set the
@@ -694,8 +709,8 @@ class CatWalk(turbogears.controllers.Controller):
     def load_column_order(self, object_name):
         """Get the column order.
 
-        If the user has rearrenged the columns order for an object,
-        this will return the prefered order as list.
+        If the user has rearranged the columns order for an object,
+        this will return the preferred order as list.
 
         @param object_name: name of the object
         @type object_name: string
@@ -706,7 +721,7 @@ class CatWalk(turbogears.controllers.Controller):
         return cols.get(object_name, [])
 
     def save_column_order(self, object_name, columns_bsv):
-        """Save the prefered order of the object's columns.
+        """Save the preferred order of the object's columns.
 
         @param object_name: name of the object
         @type object_name: string
@@ -721,7 +736,7 @@ class CatWalk(turbogears.controllers.Controller):
         self.save_state(state)
 
     def order_columns(self, object_name, cols):
-        """Return a rearrenged list of columns as configured by the user.
+        """Return a rearranged list of columns as configured by the user.
 
         @param object_name: name of the object
         @type object_name: string
@@ -771,11 +786,11 @@ class CatWalk(turbogears.controllers.Controller):
 
     ## exposed methods ##
 
-    @expose(format="json")
+    @expose('json')
     def add(self, **v):
         """Create a new instance of an object.
 
-        @param v: dictionary of submited values
+        @param v: dictionary of submitted values
 
         """
         objectName = v['objectName']
@@ -795,7 +810,7 @@ class CatWalk(turbogears.controllers.Controller):
         returnlist["msg"] = "A new instance of %s was created" % objectName
         return returnlist
 
-    @expose(format="json")
+    @expose('json')
     def update(self, **values):
         """Update the objects properties.
 
@@ -814,7 +829,7 @@ class CatWalk(turbogears.controllers.Controller):
         returnlist["msg"] = "The object was successfully updated"
         return returnlist
 
-    @expose(format="json")
+    @expose('json')
     def remove(self, objectName, id):
         """Remove and instance by id.
 
@@ -835,7 +850,7 @@ class CatWalk(turbogears.controllers.Controller):
         returnlist["msg"] = "The object was successfully deleted"
         return returnlist
 
-    @expose(format="json")
+    @expose('json')
     def remove_single_join(self, object_name, id,
             join_object_name, join_object_id):
         """Remove a single join instance by id.
@@ -855,15 +870,15 @@ class CatWalk(turbogears.controllers.Controller):
         self.remove_object(join_object_name, join_object_id)
         return self.object_instance(object_name, id)
 
-    @expose(format="json")
+    @expose('json')
     def saveModelOrder(self, models):
-        """Save the prefered order of the listed models."""
+        """Save the preferred order of the listed models."""
         self.save_model_order(models)
         return '' #return dummy string, else json will barf
 
-    @expose(format="json")
+    @expose('json')
     def columnOrder(self, objectName, cols):
-        """Save the prefered order of the object's columns.
+        """Save the preferred order of the object's columns.
 
         @param objectName: name of the object
         @type objectName: string
@@ -872,10 +887,9 @@ class CatWalk(turbogears.controllers.Controller):
 
         """
         self.save_column_order(objectName, cols)
-        """return dummy string, else json will barf"""
-        return ''
+        return '' # return dummy string, else json will barf
 
-    @expose(format="json")
+    @expose('json')
     def instances(self, objectName, start=0):
         """Get object instances.
 
@@ -888,12 +902,12 @@ class CatWalk(turbogears.controllers.Controller):
         """
         return self.object_instances(objectName, start)
 
-    @expose(format="json")
+    @expose('json')
     def manageRelatedJoins(self, objectName, id,
             join, relatedObjectName, **vargs):
         """Get related joins.
 
-        Returns a JSON structure whith a list of related joins for
+        Returns a JSON structure with a list of related joins for
         the requested object, and a list of all joins.
 
         @param objectName: name of the object
@@ -911,12 +925,12 @@ class CatWalk(turbogears.controllers.Controller):
         joins['allJoins'] = self.object_instances(relatedObjectName)
         return joins
 
-    @expose(format="json")
+    @expose('json')
     def updateJoins(self, objectName, id,
             join, joinType, joinObjectName, joins):
         """Update joins.
 
-        Drop all related joins first, then loop trought the submited joins
+        Drop all related joins first, then loop trough the submitted joins
         and set the relation.
 
         @param objectName: name of the object
@@ -929,7 +943,7 @@ class CatWalk(turbogears.controllers.Controller):
         @type joinType: string
         @param joinObjectName: name of the joined object (otherClassName)
         @type joinObjectName: string
-        @param joins: coma delimited string of join instances id's
+        @param joins: comma delimited string of join instances id's
         @type joins: string
 
         """
@@ -963,7 +977,7 @@ class CatWalk(turbogears.controllers.Controller):
         returnlist["msg"] = "The object was successfully updated"
         return returnlist
 
-    @expose(format="json")
+    @expose('json')
     def updateColumns(self, objectName, column):
         """Update a column.
 
@@ -980,7 +994,7 @@ class CatWalk(turbogears.controllers.Controller):
         self.toggle_columns_visibility_state(objectName, column)
         return self.object_instances(objectName)
 
-    @expose(format="json")
+    @expose('json')
     def updateColumnsJoinView(self, objectName, id,
             join, joinType, joinObjectName, column):
         """Update column in join view.
@@ -1007,7 +1021,7 @@ class CatWalk(turbogears.controllers.Controller):
         return self.object_joins(objectName, id,
             join, joinType, joinObjectName)
 
-    @expose(format="json")
+    @expose('json')
     def joins(self, objectName, id, join, joinType, joinObjectName):
         """Get joins.
 
@@ -1069,7 +1083,7 @@ class CatWalk(turbogears.controllers.Controller):
             values.append(col)
         return dict(objectName=object_name, id=id, values=values)
 
-    @expose(format="json")
+    @expose('json')
     def instance(self, objectName, id):
         """Get object instance.
 
@@ -1084,7 +1098,7 @@ class CatWalk(turbogears.controllers.Controller):
         """
         return self.object_instance(objectName, id)
 
-    @expose(format="json")
+    @expose('json')
     def columnsForLabel(self, objectName, foreignObjectName, foreignKeyName):
         """Get columns for label.
 
@@ -1107,7 +1121,7 @@ class CatWalk(turbogears.controllers.Controller):
                 foreignObjectName), foreignObjectName=foreignObjectName,
             objectName=objectName)
 
-    @expose(format="json")
+    @expose('json')
     def setColumnForLabel(self, objectName, foreignObjectName,
             foreignKeyName, columnName):
         """Set columns for label.
@@ -1128,7 +1142,7 @@ class CatWalk(turbogears.controllers.Controller):
         self.column_label_for_object(foreignObjectName, columnName)
         return self.columns(objectName)
 
-    @expose(format="json")
+    @expose('json')
     def columns(self, objectName, **kv):
         """Return JSON structure containing a list of column properties.
 
@@ -1136,7 +1150,7 @@ class CatWalk(turbogears.controllers.Controller):
         @type objectName: string
 
         """
-        reorder = not kv.has_key('foreignObjectName')
+        reorder = 'foreignObjectName' not in kv
         return dict(objectName=objectName,
             columns=self.object_columns(objectName),
             reorder=reorder, reordering=kv)
@@ -1151,12 +1165,12 @@ class CatWalk(turbogears.controllers.Controller):
                 objs.append(m)
         return self.order_models(objs)
 
-    @expose(format="json")
+    @expose('json')
     def list(self):
         """Return JSON structure containing a list of available objects."""
         return dict(SQLObjects=self.models())
 
-    @expose(template='kid:turbogears.toolbox.catwalk.catwalk')
+    @expose('turbogears.toolbox.catwalk.catwalk')
     def index(self):
         """Main CatWalk page.
 
