@@ -23,7 +23,7 @@ from turbogears.database import PackageHub
 from sqlobject import *
 from turbogears import identity
 
-hub = PackageHub("%s")
+hub = PackageHub('%s')
 __connection__ = hub
 
 %s
@@ -38,7 +38,7 @@ def version_file(file_spec, vtype='copy'):
     if os.path.isfile(file_spec):
         # check the 'vtype' parameter
         if vtype not in ('copy', 'rename'):
-            raise ValueError, 'Unknown vtype %r' % (vtype,)
+            raise ValueError('Unknown vtype %r' % (vtype,))
 
         # determine root file name so the extension doesn't get longer and longer...
         n, e = os.path.splitext(file_spec)
@@ -60,7 +60,7 @@ def version_file(file_spec, vtype='copy'):
                 else:
                     os.rename(file_spec, new_file)
                 return True
-        raise RuntimeError, "Can't %s %r, all names taken" % (vtype, file_spec)
+        raise RuntimeError("Can't %s %r, all names taken" % (vtype, file_spec))
     return False
 
 
@@ -72,12 +72,12 @@ class Designer(controllers.RootController):
 
     """
 
-    __label__ = "ModelDesigner"
-    __version__ = "0.1"
-    __author__ = "Ronald Jaramillo"
-    __email__ = "ronald@checkandshare.com"
-    __copyright__ = "Copyright 2005 Ronald Jaramillo"
-    __license__ = "MIT"
+    __label__ = 'ModelDesigner'
+    __version__ = '0.1'
+    __author__ = 'Ronald Jaramillo'
+    __email__ = 'ronald@checkandshare.com'
+    __copyright__ = 'Copyright 2005 Ronald Jaramillo'
+    __license__ = 'MIT'
 
     baseTemplate = 'turbogears.toolbox.designer'
     model = None
@@ -85,8 +85,10 @@ class Designer(controllers.RootController):
 
     def __init__(self):
         if not sqlobject:
-            raise ImportError, ("Cannot run the Model Designer.\n"
+            raise ImportError("Cannot run the Model Designer.\n"
                 "The SQLObject package is not installed.")
+        self.register_static_directory()
+        self.model = self.get_model_name()
 
     def set_model(self, model):
         self.model = model
@@ -97,11 +99,10 @@ class Designer(controllers.RootController):
         return get_model()
 
     def register_static_directory(self):
-        static_directory = pkg_resources.resource_filename(__name__,'static')
-        turbogears.config.update({ '/tg_toolbox/designer': {
-            'static_filter.on': True,
-            'static_filter.dir': static_directory}})
-
+        static_directory = pkg_resources.resource_filename(__name__, 'static')
+        turbogears.config.update({'/tg_toolbox/designer': {
+            'tools.staticdir.on' : True,
+            'tools.staticdir.dir': static_directory}})
 
     def column_type(self, column):
         """Given a column representation return the column type."""
@@ -189,7 +190,7 @@ class Designer(controllers.RootController):
                 column.joinMethodName, column, model_object)
         return columns
 
-    [expose(format='json')]
+    @expose('json')
     def load_current_model(self):
         model = self.get_model_name()
         current_model = {}
@@ -234,7 +235,7 @@ class Designer(controllers.RootController):
             if not os.path.exists(full_name):
                 return full_name
 
-    [expose(format='json')]
+    @expose('json')
     def save_state(self, state, name=session_file_name):
         if name != session_file_name:
             name = self.save_session_as_name(name)
@@ -263,12 +264,10 @@ class Designer(controllers.RootController):
             return False, 'Failed to save %s' % model_path
 
     def save_and_create_(self, code, order):
-        model_path = os.path.join(get_project_name(),
-            'tmp2_model.py')
+        model_path = os.path.join(get_project_name(), 'tmp2_model.py')
         model_path = os.path.abspath(model_path)
         open(model_path, 'w').write(str)
-        package = __import__(get_package_name(), {}, {},
-            ["tmp2_model"])
+        package = __import__(get_package_name(), {}, {}, ['tmp2_model'])
         package.tmp2_model.Persona.createTable(ifNotExists=True)
         model = self.get_model_name()
         model.Persona = package.tmp2_model.Persona
@@ -277,7 +276,7 @@ class Designer(controllers.RootController):
         # pk.Persona.createTable(ifNotExists=True)
         return dict(status='Tables ok')
 
-    [expose(format='json')]
+    @expose('json')
     def save_and_create(self, code, order):
         status_code, status = self.save_model(code)
         if not status_code:
@@ -293,8 +292,7 @@ class Designer(controllers.RootController):
             return dict(status='Failed to create a temporary model file: %s' % e)
 
         model = self.get_model_name()
-        package = __import__(get_package_name(), {}, {},
-            [tmp_name])
+        package = __import__(get_package_name(), {}, {}, [tmp_name])
         tmp_model = getattr(package, tmp_name)
 
         ok = []
@@ -331,7 +329,7 @@ class Designer(controllers.RootController):
     def session_exists(self):
         return os.path.exists(session_file_name)
 
-    [expose(format='json')]
+    @expose('json')
     def retrieve_sample(self, name):
         sessions_directory = pkg_resources.resource_filename(
             __name__, os.path.join('static', 'sessions'))
@@ -340,29 +338,24 @@ class Designer(controllers.RootController):
             return dict()
         return dict(session=open(full_path,'r').read())
 
-    [expose(format='json')]
+    @expose('json')
     def current_session_model(self):
         if not self.session_exists():
             return dict()
         return dict(session=open(session_file_name, 'r').read())
 
-    [expose(format='json')]
+    @expose('json')
     def save(self, code):
-        status_code, status = self.save_model(code)
+        status = self.save_model(code)[1]
         return dict(status=status)
 
-    [expose(format='json')]
+    @expose('json')
     def session_list(self):
         return dict(models=self.load_session_list())
 
-    [expose(template='%s.modelDesigner' % baseTemplate)]
+    @expose('%s.modelDesigner' % baseTemplate)
     def index(self):
-        self.register_static_directory()
-        self.model = self.get_model_name()
-        model_exists = None
-        if self.model:
-            model_exists = 1
-        return dict(model_exists=model_exists,
-            session_file_exists = self.session_exists(),
-            session_list = self.load_session_list(),
+        return dict(model_exists=bool(self.model),
+            session_file_exists=self.session_exists(),
+            session_list=self.load_session_list(),
             model_name=get_project_name())
