@@ -1,5 +1,18 @@
 """The TurboGears utility module."""
 
+_all__ = ['Bunch', 'DictObj', 'DictWrapper', 'Enum', 'setlike',
+   'get_package_name', 'get_model', 'load_project_config',
+   'ensure_sequence', 'has_arg', 'to_kw', 'from_kw', 'adapt_call',
+   'call_on_stack', 'remove_keys', 'arg_index',
+   'inject_arg', 'inject_args', 'add_tg_args', 'bind_args',
+   'recursive_update', 'combine_contexts',
+   'request_available', 'flatten_sequence', 'load_class',
+   'parse_http_accept_header', 'simplify_http_accept_header',
+   'to_unicode', 'to_utf8', 'quote_cookie', 'unquote_cookie',
+   'get_template_encoding_default', 'get_mime_type_for_format',
+   'mime_type_has_charset', 'find_precision', 'copy_if_mutable',
+   'match_ip', 'deprecated']
+
 import os
 import sys
 import re
@@ -47,6 +60,7 @@ def deprecated(message=None):
     decorate.warned = False
     return decorate
 
+
 def missing_dependency_error(name=None):
     msg = """\
 Before you can run this command, you need to install all the project's
@@ -60,6 +74,7 @@ If you are stuck, visit http://docs.turbogears.org/GettingHelp for support."""
             "found.\n\n" % name) + msg
     return msg
 
+
 class Bunch(dict):
     """Simple but handy collector of a bunch of named stuff."""
 
@@ -101,8 +116,9 @@ def Enum(*names):
 
     """
 
-    # Uncomment the following line if you don't like empty enums.
-    # assert names, "Empty enums are not supported"
+    # Uncomment the following check if you don't like empty enums.
+    # if not names:
+    #     raise ValueError("Empty enums are not supported")
 
     class EnumClass(object):
         __slots__ = names
@@ -128,10 +144,11 @@ def Enum(*names):
         def __hash__(self):
             return hash(self.__value)
         def __cmp__(self, other):
-            # C fans might want to remove the following assertion
-            # to make all enums comparable by ordinal value {;))
-            assert self.EnumType is other.EnumType, \
-                "Only values from the same enum are comparable"
+            # C fans might want to remove the following check
+            # to make all enums comparable by ordinal value
+            if not (isinstance(other, EnumValue)
+                    and self.EnumType is other.EnumType):
+                raise TypeError("Only values from the same enum are comparable")
             return cmp(self.__value, other.__value)
         def __invert__(self):
             return constants[maximum - self.__value]
@@ -164,8 +181,8 @@ class setlike(list):
 
 def get_project_meta(name):
     """Get egg-info file with that name in the current project."""
-    for dirname in os.listdir("./"):
-        if dirname.lower().endswith("egg-info"):
+    for dirname in os.listdir('./'):
+        if dirname.lower().endswith('egg-info'):
             fname = os.path.join(dirname, name)
             return fname
 
@@ -189,12 +206,12 @@ def load_project_config(configfile=None):
         sys.exit()
     package = get_package_name()
     config.update_config(configfile=configfile,
-        modulename = package + ".config")
+        modulename = package + '.config')
 
 
 def get_package_name():
     """Try to find out the package name of the current directory."""
-    package = config.get("package")
+    package = config.get('package')
     if package:
         return package
     if hasattr(sys, 'argv') and "--egg" in sys.argv:
@@ -426,11 +443,8 @@ def combine_contexts(frames=None, depth=None):
 
 def request_available():
     """Check if cherrypy.request is available."""
-    try:
-        setattr(request, "tg_dumb_attribute", True)
-        return True
-    except AttributeError:
-        return False
+    stage = getattr(request, 'stage', None)
+    return stage is not None
 
 
 def flatten_sequence(seq):
@@ -443,45 +457,6 @@ def flatten_sequence(seq):
             yield item
 
 
-def pop_from_nested_dict(params, keys):
-    """Pop a value from a nested parameter dictionary.
-
-    You must pass a list or dotted key as the key chain to the value.
-    If a value for this key chain is found, it will be removed and
-    the value will be returned. If this creates empty subkeys,
-    these will also be removed. If no single value is associated
-    with the key chain, then None will be returned.
-
-    """
-    if not isinstance(keys, list):
-        keys = keys.split('.')
-    values = []
-    for key in keys:
-        if not isinstance(params, dict) or key not in params:
-            return None
-        values.append(params)
-        params = params[key]
-    if isinstance(params, dict):
-        if None in params:
-            value = params.pop(None)
-            if params:
-                return value
-        else:
-            return None
-    else:
-        value = params
-    for key, params in reversed(zip(keys, values)):
-        del params[key]
-        if params:
-            break
-    return value
-
-
-def pop_request_params(keys):
-    """Pop a value from the nested request parameter dictionary."""
-    return pop_from_nested_dict(request.params, keys)
-
-
 def load_class(dottedpath):
     """Load a class from a module in dotted-path notation.
 
@@ -737,12 +712,12 @@ def fixentities(htmltext):
         if not entity:
             return matchobj.group(0)
         elif len(entity) == 1:
-            if entity in "&<>'\"":
+            if entity in '&<>\'"':
                 return matchobj.group(0)
-            return "&#%d;" % ord(entity)
+            return '&#%d;' % ord(entity)
         else:
             return entity
-    return re.sub("&(\w+);?", repl, htmltext)
+    return re.sub('&(\w+);?', repl, htmltext)
 
 
 if hasattr(socket, 'inet_pton') and hasattr(socket, 'AF_INET6'):
@@ -822,17 +797,3 @@ def match_ip(cidr, ip):
         ip = _inet_prefix(ip, masked)
     return ip == cidr
 
-
-__all__ = ["Bunch", "DictObj", "DictWrapper", "Enum", "setlike",
-           "get_package_name", "get_model", "load_project_config",
-           "ensure_sequence", "has_arg", "to_kw", "from_kw", "adapt_call",
-           "call_on_stack", "remove_keys", "arg_index",
-           "inject_arg", "inject_args", "add_tg_args", "bind_args",
-           "recursive_update", "combine_contexts", "request_available",
-           "flatten_sequence", "pop_from_nested_dict",
-           "pop_request_params", "load_class",
-           "parse_http_accept_header", "simplify_http_accept_header",
-           "to_unicode", "to_utf8", "quote_cookie", "unquote_cookie",
-           "get_template_encoding_default", "get_mime_type_for_format",
-           "mime_type_has_charset", "find_precision", "copy_if_mutable",
-           "match_ip", "deprecated"]
