@@ -13,7 +13,7 @@ from turbogears.util import load_class
 from turbogears.visit.api import BaseVisitManager, Visit
 
 import logging
-log = logging.getLogger("turbogears.identity.savisit")
+log = logging.getLogger('turbogears.identity.savisit')
 
 visit_class = None
 
@@ -22,25 +22,22 @@ class SqlAlchemyVisitManager(BaseVisitManager):
 
     def __init__(self, timeout):
         global visit_class
-        visit_class_path = config.get("visit.saprovider.model",
-            "turbogears.visit.savisit.TG_Visit")
+        visit_class_path = config.get('visit.saprovider.model',
+            'turbogears.visit.savisit.TG_Visit')
         visit_class = load_class(visit_class_path)
         if visit_class is None:
             msg = 'No visit class found for %s' % visit_class_path
             msg += ', did you run setup.py develop?'
             log.error(msg)
         else:
-            log.info('Successfully loaded "%s"', visit_class_path)
-
+            log.info("Successfully loaded '%s'", visit_class_path)
         if visit_class is TG_Visit:
-            # Handle it gracefully when TG_Visit is already mapped.
-            # May happen, when the visit manager is shutdown and started again
             try:
                 class_mapper(visit_class)
             except UnmappedClassError:
-                mapper(visit_class, visits_table)
-        # base-class' __init__ triggers self.create_model, so mappers need to
-        # be initialized before.
+                visit_class._map()
+        # base-class' __init__ triggers self.create_model,
+        # so mappers need to be initialized before.
         super(SqlAlchemyVisitManager, self).__init__(timeout)
 
     def create_model(self):
@@ -91,17 +88,18 @@ class SqlAlchemyVisitManager(BaseVisitManager):
                 values=dict(expiry=expiry)))
 
 
-# The Visit table
-
-visits_table = Table('tg_visit', metadata,
-    Column('visit_key', String(40), primary_key=True),
-    Column('created', DateTime, nullable=False, default=datetime.now),
-    Column('expiry', DateTime)
-)
-
+# The default Visit model class
 
 class TG_Visit(object):
 
     @classmethod
     def lookup_visit(cls, visit_key):
         return session.query(cls).get(visit_key)
+
+    @classmethod
+    def _map(cls):
+        cls._table = Table('visit', metadata,
+            Column('visit_key', String(40), primary_key=True),
+            Column('created', DateTime, nullable=False, default=datetime.now),
+            Column('expiry', DateTime))
+        cls._mapper = mapper(cls, cls._table)
