@@ -1,35 +1,35 @@
+"""Internationalization support for TurboGears widgets"""
+
+__all__ = ['LocalizableJSLink', 'CalendarLangFileLink']
+
 import os
 import codecs
 from cherrypy import request
 from turbogears.i18n import get_locale
 from turbogears import startup, config
 from turbogears.util import parse_http_accept_header
-from turbogears.i18n.utils import lang_in_gettext_format
-from turbogears.widgets.base import JSLink, CoreWD, RenderOnlyWD, static
-
-__all__ = ["LocalizableJSLink", "CalendarLangFileLink"]
+from turbogears.widgets.base import JSLink, CoreWD, RenderOnlyWD
 
 
 class LocalizableJSLink(JSLink):
-    """
-    Provides a simple way to include language-specific data in your
-    Javascript code.
+    """Provides a simple way to include language-specific data in your JS code.
 
     Language file to use is determined from the user's locale or from the 'language'
     parameter. If there is no language file for the language (determined via
     'supported_languages' parameter) than 'default_language' is used.
+
     """
 
     default_language = 'en'
     supported_languages = ['en']
     params = ['default_language', 'language', 'supported_languages']
     params_doc = {
-        'language' : 'language code to use ' \
-            '(overrides user locale setting which is the default)',
-        'default_language' : 'language code to use ' \
-                'if specified language is not supported',
-        'supported_languages' : 'list of supported language codes ' \
-                ' (which means corresponding language files exist)',
+        'language': "language code to use "
+            " (overrides user locale setting which is the default)",
+        'default_language': "language code to use"
+            " if specified language is not supported",
+        'supported_languages': "list of supported language codes"
+            " (which means corresponding language files exist)"
     }
 
     def update_params(self, d):
@@ -41,16 +41,16 @@ class LocalizableJSLink(JSLink):
 
 
 class LocalizableJSLinkDesc(CoreWD, RenderOnlyWD):
+
     name = "Localizable JS Link"
-    for_widget = LocalizableJSLink("turbogears", "js/yourscript-%(lang)s.js")
+    for_widget = LocalizableJSLink('turbogears', 'js/yourscript-%(lang)s.js')
 
 
 _norm_tag = ''.join([(c.islower() or c.isdigit() or c == '-')
-    and c or c.isupper() and c.lower() or ' '
-    for c in map(chr, xrange(256))])
+    and c or c.isupper() and c.lower() or ' ' for c in map(chr, xrange(256))])
 
 def norm_tag(tag):
-    """Normalize string to alphanumeric ascii chars, hypens and underscores.
+    """Normalize string to alphanumeric ascii chars, hyphens and underscores.
 
     The length is limited to 16 characters and other characters are
     collapsed to single underscore, or ignored at the start or end.
@@ -79,7 +79,7 @@ class CalendarLangFileLink(LocalizableJSLink):
 
     def update_params(self, d):
         languages = parse_http_accept_header(
-            request.headers.get("Accept-Language")) or []
+            request.headers.get('Accept-Language')) or []
         language = d.get('language')
         if language and language != '*':
             languages.insert(0, language)
@@ -87,18 +87,18 @@ class CalendarLangFileLink(LocalizableJSLink):
         default_language = norm_tag(self.default_language)
         languages.append(default_language)
         charsets = parse_http_accept_header(
-            request.headers.get("Accept-Charset")) or []
+            request.headers.get('Accept-Charset')) or []
         charsets = map(norm_charset, charsets)
         default_charset = norm_charset(self.default_charset)
-        charset = norm_charset(config.get("kid.encoding"))
+        charset = norm_charset(config.get(self.engine_name == 'kid'
+            and 'kid.encoding' or 'genshi.default_encoding'))
         if charset and charset != default_charset:
             charsets.append(charset)
         charsets.append(default_charset)
-        path = "/tg_widgets/%s" % self.mod
-        base_dir = config.get("static_filter.dir", path=path)
-        base_name = "calendar/lang/calendar-"
+        path = '/tg_widgets/%s' % self.mod
+        base_dir = config.app[path].get('tools.staticdir.dir')
+        base_name = 'calendar/lang/calendar-'
         def find_link():
-            params = dict()
             for lang in languages:
                 if not lang or lang == '*':
                     lang = default_language
@@ -111,9 +111,9 @@ class CalendarLangFileLink(LocalizableJSLink):
                         file_name += '-' + charset.replace('-', '_')
                     file_name += '.js'
                     if os.path.exists(os.path.join(base_dir, file_name)):
-                        path = "/%stg_widgets/%s" % (startup.webpath, self.mod)
-                        link = "%s/%s" % (path, file_name)
+                        path = '%s/tg_widgets/%s' % (startup.webpath, self.mod)
+                        link = '%s/%s' % (path, file_name)
                         return (link, language, charset)
                     if charset == default_charset:
                         break
-        d["link"], d['language'], d['charset'] = find_link()
+        d['link'], d['language'], d['charset'] = find_link()
